;***************************************;***************************************
;                                              
;    Filename:							OBD.ASM 
;    Date:                              1/18/2011    
;    File Version:                      0.1
;                                          
;    Author:                            jeff bachiochi    
;    Company:                           imagine that  
;                                       www.imaginethatnow.com
;    
;***************************************;***************************************
;                                             
;    Files required: P18F2480.INC              
;
;	PWM bittime 10400 = 24uS (timer1 timeout = 1/6 bittime or 4uS)
;
;	This program emulates a minimum number of the ELM AT command set
;	More commands can be added as required
;
;	<CR>		Repeat Last COmmand
;	E0, E1		Echo OFF, ON 
;	L0, L1		Linefeed OFF, ON
;	DP			Describe Protocol
;	DPN			Describe Protocol by Number
;	H0, H1		Headers ON, OFF
;	S0, S1		Spaces ON, OFF
;	SHxyz		Set Header to x y z
;	SHxxyyzz	Set Header to xx yy zz 
;	TPh			Try Protocol h
;	TPAh		Try Protocol h else auto search
;	CAF0, CAF1	Automatic formatting ON, OFF
;	FI			Perform Fast Init
;	SI			Perform Slow Init
;
;	ELM327 micro available from www.elmelectronics.com
;                                             
;***************************************;***************************************
;
	LIST P=18F2480, F=INHX32			; directive to define processor
	#include <P18F2480.INC>				; processor specific variable definitions
;
;***************************************;***************************************
;
;	Configuration bits
;
;***************************************;***************************************
;
;   Oscillator Selection bits:
;     OSC = LP             LP oscillator
;    CONFIG	OSC = XT             		; XT oscillator
;     OSC = HS             HS oscillator
;     OSC = RC             External RC oscillator, CLKO function on RA6
;     OSC = EC             EC oscillator, CLKO function on RA6
;     OSC = ECIO           EC oscillator, port function on RA6
    CONFIG	OSC = HSPLL          		; HS oscillator, PLL enabled 
;									    (Clock Frequency = 4 x FOSC1)
;     OSC = RCIO           External RC oscillator, port function on RA6
;	CONFIG	OSC = IRCIO67        		; Internal oscillator block,
;										 port function on RA6 and RA7
;	CONFIG	OSC = IRCIO7         		; Internal oscillator block,
;										 CLKO function on RA6, port function on RA7
;
;   Fail-Safe Clock Monitor Enable bit:
;     FCMEN = OFF          Fail-Safe Clock Monitor disabled
;     FCMEN = ON           Fail-Safe Clock Monitor enabled
;
;   Internal/External Oscillator Switchover bit:
;     IESO = OFF           Oscillator Switchover mode disabled
;     IESO = ON            Oscillator Switchover mode enabled
;
;   Power-up Timer Enable bit:
;     PWRT = ON            PWRT enabled
;     PWRT = OFF           PWRT disabled
;
;   Brown-out Reset Enable bits:
	CONFIG	BOREN = OFF          		; Brown-out Reset disabled 
;     BOREN = SBORENCTRL   Brown-out Reset enabled and controlled by
;										 software (SBOREN is enabled)
;     BOREN = BOACTIVE     Brown-out Reset enabled in hardware only and
;										 disabled in Sleep mode (SBOREN is disabled)
;     BOREN = BOHW         Brown-out Reset enabled in hardware only
;										 (SBOREN is disabled)
;
;   Brown-out Reset Voltage bits:
;     BORV = 0             Maximum Setting
;     BORV = 1             
;     BORV = 2             
;     BORV = 3             Minimum Setting
;
;   Watchdog Timer Enable bit:
;     WDT = OFF            WDT disabled (control is placed on the SWDTEN bit)
;     WDT = ON             WDT enabled
;
;   Watchdog Timer Postscale Select bits:
;     WDTPS = 1            1:1
;     WDTPS = 2            1:2
;     WDTPS = 4            1:4
;     WDTPS = 8            1:8
;     WDTPS = 16           1:16
;     WDTPS = 32           1:32
;     WDTPS = 64           1:64
;     WDTPS = 128          1:128
;     WDTPS = 256          1:256
;     WDTPS = 512          1:512
;     WDTPS = 1024         1:1024
;     WDTPS = 2048         1:2048
;     WDTPS = 4096         1:4096
;     WDTPS = 8192         1:8192
;     WDTPS = 16384        1:16384
;     WDTPS = 32768        1:32768
;
;   MCLR Pin Enable bit:
;     MCLRE = OFF          RE3 input pin enabled; MCLR disabled
;     MCLRE = ON           MCLR pin enabled; RE3 input pin disabled
;
;   Low-Power Timer 1 Oscillator Enable bit:
;     LPT1OSC = OFF        Timer1 configured for higher power operation
;     LPT1OSC = ON         Timer1 configured for low-power operation
;
;   PORTB Pins Configured for A/D:
;     PBADEN = OFF         PORTB<4> and PORTB<1:0> Configured as Digital I/O Pins on Reset
;     PBADEN = ON          PORTB<4> and PORTB<1:0> Configured as Analog Pins on Reset
;
;   Background Debugger Enable bit:
	CONFIG	DEBUG = ON           		; Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug
;     DEBUG = OFF          Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
;
;   Extended Instruction Set Enable bit:
;     XINST = OFF          Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
;     XINST = ON           Instruction set extension and Indexed Addressing mode enabled
;
;   Boot Block Size:
;     BBSIZ = 1024         1K words (2K bytes) Boot Block
;     BBSIZ = 2048         2K words (4K bytes) Boot Block
;
;   Single-Supply ICSP Enable bit:
	CONFIG	LVP = OFF            		; Single-Supply ICSP disabled
;     LVP = ON             Single-Supply ICSP enabled
;
;   Stack Full/Underflow Reset Enable bit:
;     STVREN = OFF         Stack full/underflow will not cause Reset
;     STVREN = ON          Stack full/underflow will cause Reset
;
;   Code Protection Block 0:
;     CP0 = ON             Block 0 (000800-001FFFh) code-protected
;     CP0 = OFF            Block 0 (000800-001FFFh) not code-protected
;
;   Code Protection Block 1:
;     CP1 = ON             Block 1 (002000-003FFFh) code-protected
;     CP1 = OFF            Block 1 (002000-003FFFh) not code-protected
;
;   Boot Block Code Protection:
;     CPB = ON             Boot block (000000-0007FFh) code-protected
;     CPB = OFF            Boot block (000000-0007FFh) not code-protected
;
;   Data EEPROM Code Protection:
;     CPD = ON             Data EEPROM code-protected
;     CPD = OFF            Data EEPROM not code-protected
;
;   Write Protection Block 0:
;     WRT0 = ON            Block 0 (000800-001FFFh) write-protected
;     WRT0 = OFF           Block 0 (000800-001FFFh) not write-protected
;
;   Write Protection Block 1:
;     WRT1 = ON            Block 1 (002000-003FFFh) write-protected
;     WRT1 = OFF           Block 1 (002000-003FFFh) not write-protected
;
;   Boot Block Write Protection:
;     WRTB = ON            Boot block (000000-0007FFh) write-protected
;     WRTB = OFF           Boot block (000000-0007FFh) not write-protected
;
;   Configuration Register Write Protection:
;     WRTC = ON            Configuration registers (300000-3000FFh) write-protected
;     WRTC = OFF           Configuration registers (300000-3000FFh) not write-protected
;
;   Data EEPROM Write Protection:
;     WRTD = ON            Data EEPROM write-protected
;     WRTD = OFF           Data EEPROM not write-protected
;
;   Table Read Protection Block 0:
;     EBTR0 = ON           Block 0 (000800-001FFFh) protected from table reads executed in other blocks
;     EBTR0 = OFF          Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
;
;   Table Read Protection Block 1:
;     EBTR1 = ON           Block 1 (002000-003FFFh) protected from table reads executed in other blocks
;     EBTR1 = OFF          Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
;
;   Boot Block Table Read Protection:
;     EBTRB = ON           Boot block (000000-0007FFh) protected from table reads executed in other blocks
;     EBTRB = OFF          Boot block (000000-0007FFh) not protected from table reads executed in other blocks
; 
;
;***************************************;***************************************
;
;	Constants
;
;***************************************;***************************************
;
;***** PORTA
BAT			equ	0						;  
V_SEL		equ	1						; 
B_PLUS		equ	2						; 
LED5		equ	3						; 
LED6		equ	4						;  
LED7		equ	5						; 
;			equ	6						; 
;			equ	7						; 
;
;***** PORTB
K			equ	0						;  
L			equ	1						; 
CANTX		equ	2						; 
CANRX		equ	3						; 
LED1		equ	4						;  
LED2		equ	5						; 
LED3		equ	6						; 
LED4		equ	7						; 
;
;***** PORTC
B_PLUS_SEN	equ	0						;  
K_SEN		equ	1						; 
B_MINUS_SEN	equ	2						; 
B_MINUS		equ	3						; 
;			equ	4						;  
;			equ	5						; 
;RX			equ	6						; 
;TX			equ	7						;
;
;***** FLAG 
RCR			equ	0						; Carriage Return Received
FC			equ	1						; First Character
AF			equ	2						; auto flag
HF			equ	3						; header flag
SF			equ	4						; add spaces flag
HSF			equ	5						; header size
CAFF		equ	6						; auto formatting
AUTOINPROCESS	equ	7					; 1=trying auto mode
;
;***** FLAG1 						
DISPLAYPROTOCOL	equ 0					; display protocol on each transmission
LASTVPWSTATE	equ	1					; 1=active, 0=passive
INIT		equ	2						; 1=fast init, 0=slow init
AWAKE		equ	3						; 1=auto awake running
TICK		equ	4						; 1=1 second has passed
T1TOGGLE	equ	5						; 24mS
;
;***** RFLAG
GOTDATA		equ	0						; 1=Good Data
FRAME		equ	1						; 1=Framing Error
GIVEUP		equ	2						; 1=Timeout 
ARBITRATION	equ	3						; 1=K_SEN found to be active
DISPLAYRESPONSE	equ	4					; 1=Display, 0=quiet
;
;***** CFLAG
SI			equ	0						; slow init request
FI			equ	1						; fast init request
SFRAME		equ	2						; 1=CAN Single Frame
FFRAME		equ	3						; 1=CAN First Frame
CFRAME		equ	4						; 1=CAN Consecutive Frame
FCONTROL	equ	5						; 1=CAN Flow Control
;
;***** EFLAG
BFULL		equ	0						; 1=buffer full
BBUSY		equ	1						; 1=busy bus
DERROR		equ	2						; 1=data error
NDATA		equ	3						; 1=no data
UCONNECT	equ	4						; 1=unable to connect
QMARK		equ	5						; 1=unknown command
;
UARTInputBufferLength	equ	0x20
UARTOutputBufferLength	equ	0x80
XTAL		equ		d'40000'			; Actual XTAL/100
PLL			equ		d'4'				; PLL * 4
BAUD		equ		d'1152'				; Actual BAUD/100
RAW			equ		XTAL/BAUD
BRGHEN		equ		d'4'				; BRGH * 4
BRG16EN  	equ		d'4'				; BRG16 * 4
FACTOR		equ		d'64'/((BRGHEN*BRG16)*PLL)
UARTRELOAD	equ		(RAW/FACTOR)-1
PRIORITY29	equ		0x18
;
HEADERP1	equ		0x616AF1
HEADERP2	equ		0x686AF1
HEADERP3	equ		0x686AF1
HEADERP4	equ		0xC233F1
HEADERP5	equ		0xC233F1
HEADERP6	equ		0x0007DF
HEADERP7	equ		0xDB33F1
HEADERP8	equ		0x0007DF
HEADERP9	equ		0xDB33F1
;
T2_64US		equ		4*D'64'				; 4 * ?uS
T2_32US		equ		4*D'32'				; 4 * ?uS
T2_8US		equ		4*D'8'				; 4 * ?uS
LASTPARAMETER	equ	D'51'
;
T1RELOAD25MS	equ		D'25'			; 25mS
T1RELOAD	equ		~(D'500'*T1RELOAD25MS); Timer 1 reload Value
; TIMER 3 = 2uS/count
T3_5MS		equ		~(D'500' * D'5')	; 5mS
T3_20MS		equ		~(D'500' * D'20')	; 20mS
T3_25MS		equ		~(D'500' * D'25')	; 25mS
T3_50MS		equ		~(D'500' * D'50')	; 50mS
RetryCount	equ		5	
;
DEFAULT_PARAMETER0	equ	0xFF			; MA Monitor All 0=ON (default OFF)
DEFAULT_PARAMETER1	equ	0xFF			; HA Display Headers 0=ON (default OFF)
DEFAULT_PARAMETER2	equ	0xFF			; AL Allow Long Messages
DEFAULT_PARAMETER3	equ	D'32'			; ST Timeout for No Data
DEFAULT_PARAMETER4	equ	0x01			; AT Adaptive Timing (default 2)
DEFAULT_PARAMETER5	equ	0xF1			; ?
DEFAULT_PARAMETER6	equ	D'9'			; My address (default 0xF1)
DEFAULT_PARAMETER7	equ	0x00			; last protocol (default 0x09)
DEFAULT_PARAMETER8	equ	0xFF			; ?
DEFAULT_PARAMETER9	equ	0x00			; E Character Echo 0=ON (default OFF)
DEFAULT_PARAMETER10	equ	0x0A			; Linefeed Character (default 0x0A)
DEFAULT_PARAMETER11	equ	0xFF			; ?
DEFAULT_PARAMETER12	equ	D'104'			; RS232 buadrate divisor when pin6=1
DEFAULT_PARAMETER13	equ	0x0D			;  
DEFAULT_PARAMETER14	equ	0x9A			; Power Control Options
DEFAULT_PARAMETER15	equ	0x00			; ?	
DEFAULT_PARAMETER16	equ	D'13'			; J1850 settling time
DEFAULT_PARAMETER17	equ	0x00			; J1850 break signal monitoring time
DEFAULT_PARAMETER18	equ	0xFF			; J1850 pin3 output polarity
DEFAULT_PARAMETER19	equ	D'50'			; Auto search time between Protocol 1&2
DEFAULT_PARAMETER20	equ	D'10'			; Min intermessage time Protocols 3-5
DEFAULT_PARAMETER21	equ	0xFF			; IB ISO baud rate
DEFAULT_PARAMETER22	equ	D'146'			; SW ISO wakeup messagge repeat rate
DEFAULT_PARAMETER23	equ	0x00			; Auto search time between Protocol 4&5
DEFAULT_PARAMETER24	equ	D'40'			; Auto search time between Protocol 5&6
DEFAULT_PARAMETER25	equ	0xFF			; ?
DEFAULT_PARAMETER26	equ	0xFF			; ?
DEFAULT_PARAMETER27	equ	0xFF			; ?
DEFAULT_PARAMETER28	equ	0xFF			; ?
DEFAULT_PARAMETER29	equ	0xFF			; ?
DEFAULT_PARAMETER30	equ	0xFF			; ?
DEFAULT_PARAMETER31	equ	0xFF			; ?	
DEFAULT_PARAMETER32	equ	0xFF			; ?
DEFAULT_PARAMETER33	equ	0xFF			; CSM CAN Silent Mode  
DEFAULT_PARAMETER34	equ	0xFF			; ?
DEFAULT_PARAMETER35	equ	0xFF			; ?
DEFAULT_PARAMETER36	equ	0x00			; CAF CAN Auto Formatting  
DEFAULT_PARAMETER37	equ	0x00			; CFC CAN Auto Flow Control  
DEFAULT_PARAMETER38	equ	0x00			; CAN filler byte (default=0)  
DEFAULT_PARAMETER39	equ	0xFF			; ? 
DEFAULT_PARAMETER40	equ	0xFF			; ?
DEFAULT_PARAMETER41	equ	0xFF			; D0/D1 Display DLC Data Length CAN
DEFAULT_PARAMETER42	equ	0x38			; CAN Error Checking 
DEFAULT_PARAMETER43	equ	D'2'			; Protocol A CAN baud rate divisor
DEFAULT_PARAMETER44	equ	0xE0			; Protocol B CAN options 
DEFAULT_PARAMETER45	equ	D'4'			; Protocol B CAN baud rate divisor 
DEFAULT_PARAMETER46	equ	0x80			; Protocol C CAN options   
DEFAULT_PARAMETER47	equ	D'10'			; Protocol C CAN baud rate divisor 			
;
;***************************************;***************************************
;
;	Variable definitions
;
;***************************************;***************************************
;
			UDATA_ACS
WREG_TEMP	RES	1						; variable in RAM for context saving 
STATUS_TEMP	RES	1						; variable in RAM for context saving
BSR_TEMP	RES	1						; variable in RAM for context saving
UARTInputBufferHead		res	1			; access RAM
UARTOutputBufferHead	res	1
UARTOutputBufferTail	res	1
ITEMP		res 1
ICHAR_RX	res 1
ICHAR_TX	res	1
TEMP		res	1
TEMP1		res	1
TEMPL		res	1
TEMPH		res	1
FLAG		res	1
FLAG1		res	1
RFLAG		res	1
CFLAG		res	1
EFLAG		res	1
CHAR		res	1
PROTOCOL	res	1
TPROTOCOL	res	1
LASTPROTOCOL	res	1
RXSTAT		res	1
VALUE		res	1
RETRY		res	1
TRY			res	1
STATE		res	1
PCI			res	1
PRIORITY	res	1
TMR1RELOADH	res	1
TMR1RELOADL	res	1
TMR3H_RELOAD	res	1
TMR3L_RELOAD	res	1
T1COUNT		res	1
CHECKSUM	res	1
THEADERU	res	1
THEADERH	res	1
THEADERL	res	1
HEADERU		res	1
HEADERH		res	1
HEADERL		res	1
TXSIDH		res	1
TXSIDL		res	1
TXEIDH		res	1
TXEIDL		res	1
TXBDLC		res	1
TXBYTE0		res	1
TXBYTE1		res	1
TXBYTE2		res	1
TXBYTE3		res	1
TXBYTE4		res	1
TXBYTE5		res	1
TXBYTE6		res	1
TXBYTE7		res	1
RXSIDH		res	1
RXSIDL		res	1
RXEIDH		res	1
RXEIDL		res	1
RXBDLC		res	1
RXBYTE0		res	1
RXBYTE1		res	1
RXBYTE2		res	1
RXBYTE3		res	1
RXBYTE4		res	1
RXBYTE5		res	1
RXBYTE6		res	1
RXBYTE7		res	1
TXCOUNT		res	1
TXBBHU		res	1
TXBBHH		res	1
TXBBHL		res	1
TXBBD0		res	1
TXBBD1		res	1
TXBBD2		res	1
TXBBD3		res	1
TXBBD4		res	1
TXBBD5		res	1
TXBBD6		res	1
TXBBD7		res	1
RRESPONSES	res	1
RESPONSECOUNT	res	1
RXCOUNT		res	1
RXBBHU		res	1
RXBBHH		res	1
RXBBHL		res	1
RXBBD0		res	1
RXBBD1		res	1
RXBBD2		res	1
RXBBD3		res	1
RXBBD4		res	1
RXBBD5		res	1
RXBBD6		res	1
RXBBD7		res	1
RXBBD8		res	1
;
UARTBufferBase	UDATA	0x100
UARTInputBuffer			res	UARTInputBufferLength	; Linear Buffer
UARTOutputBuffer		res	UARTOutputBufferLength	; Ring Buffer
;
PARAMETER0	res	1						; MA Monitor All 0=ON (default OFF)
PARAMETER1	res	1						; HA Display Headers 0=ON (default OFF)
PARAMETER2	res	1						; AL Allow Long Messages
										; 	0=ON (default OFF)
PARAMETER3	res	1						; ST Timeout for No Data
										;	value*4.096mS (default 32)
PARAMETER4	res	1						; AT Adaptive Timing (default 2)
										; 0=OFF, 1=auto1, 2= auto2 
PARAMETER5	res	1						; ?
PARAMETER6	res	1						; My address (default 0xF1)
PARAMETER7	res	1						; last protocol (default 0x09)
PARAMETER8	res	1						; ?
PARAMETER9	res	1						; E Character Echo 0=ON (default OFF)
PARAMETER10	res	1						; Linefeed Character (default 0x0A)
PARAMETER11	res	1						; ?
PARAMETER12	res	1						; RS232 buadrate divisor when pin6=1
										; 19,200 = 208
										; 38,400 = 104 (default) 
										; 57,600 = 69
										; 115,200 = 35
										; 230,400 = 17
										; 500,000 = 8
PARAMETER13	res	1						; Carriage Return Character
										;	(default 0x0D)
PARAMETER14	res	1						; Power Control Options
										; bit7 = Master Enable 
										;	0=OFF, 1=ON (default 1)
										; bit6 = pin16 full power level 
										;	0=low, 1=high (default 0)
										; bit5 = Auto LP control
										;	0=disabled, 1=enabled (default 0)
										; bit4 = Auto LP timeout minutes 
										;	0=5, 1=20 (default 1)
										; bit3 = auto LP warning 
										;	0=disabled, 1=enabled (default 1)
										; bit2 = ignition control 
										;	0=disabled, 1=enabled (default 0)
										; bit1 = ignition delay seconds
										;	0=1, 1=5 (default 1)
										; bit0 = reserved 
										;	(default 0)																						 																				
PARAMETER15	res	1						; ?
PARAMETER16	res	1						; J1850 settling time
										;	value*4.096mS (default 13)
PARAMETER17	res	1						; J1850 break signal monitoring time
										;	0=OFF, 1=ON (default 1)				
PARAMETER18	res	1						; J1850 pin3 output polarity
										;	0=invert, 1=normal (default 1)	
PARAMETER19	res	1						; Auto search time between Protocol 1&2
										;	value*4.096mS (default 32)
PARAMETER20	res	1						; Minimum intermessage time Protocols
										; 	 3-5 value*2.2mS (default 10)
PARAMETER21	res	1						; IB ISO baud rate 
										;	0=9,600, 1=10,400 (default 1)
PARAMETER22	res	1						; SW ISO wakeup messagge repeat rate
										;	value*20.48mS (default 146)	
PARAMETER23	res	1						; Auto search time between Protocol 4&5
										;	value*4.096mS (default 0)
PARAMETER24	res	1						; Auto search time between Protocol 5&6
										;	value*20.48mS (default 40)
PARAMETER25	res	1						; ?
PARAMETER26	res	1						; ?						;
PARAMETER27	res	1						; ?
PARAMETER28	res	1						; ?
PARAMETER29	res	1						; ?
PARAMETER30	res	1						; ?
PARAMETER31	res	1						; ?
PARAMETER32	res	1						; ?
PARAMETER33	res	1						; CSM CAN Silent Mode
										;	0=OFF, 1=ON (default 1)	
PARAMETER34	res	1						; ?
PARAMETER35	res	1						; ?
PARAMETER36	res	1						; CAF CAN Auto Formatting
										;	0=ON, 1=OFF (default 0)
PARAMETER37	res	1						; CFC CAN Auto Flow Control
										;	0=ON, 1=OFF (default 0)
PARAMETER38	res	1						; CAN filler byte (default=0)
PARAMETER39	res	1						; ?
PARAMETER40	res	1						; ?
PARAMETER41	res	1						; D0/D1 Display DLC Data Length CAN
										;	0=ON, 1=OFF (default 1)
PARAMETER42	res	1						; CAN Error Checking
										; bit7 = Data Length 
										;	0=any, 1=8 (default 0)
										; bit6 = PCI=0
										;	0=allow, 1=disallow (default 0)
										; bit5 = search after ERR94 
										;	0=normal, 1=CAN blocked (default 1)
										; bit4 = search after LV 
										;	0=normal, 1=CAN blocked (default 1)
										; bit3 = wiring test 
										;	0=bypass, 1=perform (default 1)
										; bit2 = reserved
										;	(default 0)
										; bit1 = reserved
										;	(default 0)
										; bit0 = reserved
										;	(default 0)																																																																						
PARAMETER43	res	1						; Protocol A (SAE J1939) CAN baud rate divisor
										; 	value*500 (default 2)
PARAMETER44	res	1						; Protocol B CAN options
										; bit7 = transmit ID length
										;	0=29-bit, 1=11-bit (default 1)
										; bit6 = data length
										;	0=8, 1=variable (default 1)
										; bit5 = receive ID length
										;	0=29-bit, 1=11-bit (default 1)
										; bit4 = baud rate multiplier
										;	0=times 1, 1=times 8/7 (default 0)										
										; bit3 = reserved
										;	(default 0)
										; bit2:0 = data format
										;	000 = none (default)
										;	001 = ISO 15765-5
										;	010 = SAE J1939																				
PARAMETER45	res	1						; Protocol B CAN baud rate divisor
										; 	value*500 (default 2)
PARAMETER46	res	1						; Protocol C CAN options
										; bit7 = transmit ID length
										;	0=29-bit, 1=11-bit (default 1)
										; bit6 = data length
										;	0=8, 1=variable (default 1)
										; bit5 = receive ID length
										;	0=29-bit, 1=11-bit (default 1)
										; bit4 = baud rate multiplier
										;	0=times 1, 1=times 8/7 (default 0)										
										; bit3 = reserved
										;	(default 0)
										; bit2:0 = data format
										;	000 = none (default)
										;	001 = ISO 15765-5
										;	010 = SAE J1939
PARAMETER47	res	1						; Protocol C CAN baud rate divisor
										; 	value*500 (default 2)
; my added parameters
PARAMETER48	res	1						; (LF on pin 7 input)
PARAMETER49	res	1						; Timer1 ReloadH
PARAMETER50	res	1						; Timer1 ReloadL
PARAMETER51	res	1						; default Protocol
;
P1HEADERU	res	1
P1HEADERH	res	1
P1HEADERL	res	1
P2HEADERU	res	1
P2HEADERH	res	1
P2HEADERL	res	1
P3HEADERU	res	1
P3HEADERH	res	1
P3HEADERL	res	1
P4HEADERU	res	1
P4HEADERH	res	1
P4HEADERL	res	1
P5HEADERU	res	1
P5HEADERH	res	1
P5HEADERL	res	1
P6HEADERU	res	1
P6HEADERH	res	1
P6HEADERL	res	1
P7HEADERU	res	1
P7HEADERH	res	1
P7HEADERL	res	1
P8HEADERU	res	1
P8HEADERH	res	1
P8HEADERL	res	1
P9HEADERU	res	1
P9HEADERH	res	1
P9HEADERL	res	1
P10HEADERU	res	1
P10HEADERH	res	1
P10HEADERL	res	1
P11HEADERU	res	1
P11HEADERH	res	1
P11HEADERL	res	1
P12HEADERU	res	1
P12HEADERH	res	1
P12HEADERL	res	1
;
			UDATA	0x200
;
RX1COUNT	res 1
RX1BBHU		res	1
RX1BBHH		res	1
RX1BBHL		res	1
RX1BBD0		res	1
RX1BBD1		res	1
RX1BBD2		res	1
RX1BBD3		res	1
RX1BBD4		res	1
RX1BBD5		res	1
RX1BBD6		res	1
RX1BBD7		res	1
RX1BBD8		res	1
;
RX2COUNT	res 1
RX2BBHU		res	1
RX2BBHH		res	1
RX2BBHL		res	1
RX2BBD0		res	1
RX2BBD1		res	1
RX2BBD2		res	1
RX2BBD3		res	1
RX2BBD4		res	1
RX2BBD5		res	1
RX2BBD6		res	1
RX2BBD7		res	1
RX2BBD8		res	1
;
RX3COUNT	res 1
RX3BBHU		res	1
RX3BBHH		res	1
RX3BBHL		res	1
RX3BBD0		res	1
RX3BBD1		res	1
RX3BBD2		res	1
RX3BBD3		res	1
RX3BBD4		res	1
RX3BBD5		res	1
RX3BBD6		res	1
RX3BBD7		res	1
RX3BBD8		res	1
;
RX4COUNT	res 1
RX4BBHU		res	1
RX4BBHH		res	1
RX4BBHL		res	1
RX4BBD0		res	1
RX4BBD1		res	1
RX4BBD2		res	1
RX4BBD3		res	1
RX4BBD4		res	1
RX4BBD5		res	1
RX4BBD6		res	1
RX4BBD7		res	1
RX4BBD8		res	1
;
RX5COUNT	res 1
RX5BBHU		res	1
RX5BBHH		res	1
RX5BBHL		res	1
RX5BBD0		res	1
RX5BBD1		res	1
RX5BBD2		res	1
RX5BBD3		res	1
RX5BBD4		res	1
RX5BBD5		res	1
RX5BBD6		res	1
RX5BBD7		res	1
RX5BBD8		res	1
;
RX6COUNT	res 1
RX6BBHU		res	1
RX6BBHH		res	1
RX6BBHL		res	1
RX6BBD0		res	1
RX6BBD1		res	1
RX6BBD2		res	1
RX6BBD3		res	1
RX6BBD4		res	1
RX6BBD5		res	1
RX6BBD6		res	1
RX6BBD7		res	1
RX6BBD8		res	1
;
RX7COUNT	res 1
RX7BBHU		res	1
RX7BBHH		res	1
RX7BBHL		res	1
RX7BBD0		res	1
RX7BBD1		res	1
RX7BBD2		res	1
RX7BBD3		res	1
RX7BBD4		res	1
RX7BBD5		res	1
RX7BBD6		res	1
RX7BBD7		res	1
RX7BBD8		res	1
;
RX8COUNT	res 1
RX8BBHU		res	1
RX8BBHH		res	1
RX8BBHL		res	1
RX8BBD0		res	1
RX8BBD1		res	1
RX8BBD2		res	1
RX8BBD3		res	1
RX8BBD4		res	1
RX8BBD5		res	1
RX8BBD6		res	1
RX8BBD7		res	1
RX8BBD8		res	1
;
;***************************************;***************************************
;
;	EEPROM data
;
;***************************************;***************************************
;
DATA_EEPROM	code_pack 	0xf00000

PP00	DE		0xFF
PP01	DE		0xFF
PP02	DE		0xFF
PP03	DE		0x32
PP04	DE		0x01
PP05	DE		0xFF
PP06	DE		0xF1
PP07	DE		0x09
PP08	DE		0xFF
PP09	DE		0x00
PP0A	DE		0x0A
PP0B	DE		0xFF
PP0C	DE		0x68
PP0D	DE		0x0D
PP0E	DE		0x9A
PP0F	DE		0xFF
PP10	DE		0x0D
PP11	DE		0x00
PP12	DE		0xFF
PP13	DE		0x32
PP14	DE		0xFF
PP15	DE		0x0A
PP16	DE		0xFF
PP17	DE		0x92
PP18	DE		0x00
PP19	DE		0x28
PP1A	DE		0xFF
PP1B	DE		0xFF
PP1C	DE		0xFF
PP1D	DE		0xFF
PP1E	DE		0xFF
PP1F	DE		0xFF
PP20	DE		0xFF
PP21	DE		0xFF
PP22	DE		0xFF
PP23	DE		0xFF
PP24	DE		0x00
PP25	DE		0x00
PP26	DE		0x00
PP27	DE		0xFF
PP28	DE		0xFF
PP29	DE		0xFF
PP2A	DE		0x38
PP2B	DE		0x02
PP2C	DE		0xE0
PP2D	DE		0x04
PP2E	DE		0x80
PP2F	DE		0x0A
PP30	DE		0xFF					; parameter48
PP31	DE		0xFF					; parameter49
PP32	DE		0xFF					; parameter50
PP33	DE		0x06					; parameter51
;
;***************************************;***************************************
;
;	Reset vector
;
;***************************************;***************************************
;
RESET_VECTOR	CODE	0x0000
		nop
		goto	Init					;go to initialization code
;
;***************************************;***************************************
;
;	High priority interrupt vector
;
;***************************************;***************************************
;
HI_INT_VECTOR	CODE	0x0008

		bra	HighInt		;go to high priority interrupt routine
;
;***************************************;***************************************
;
;	Low priority interrupt vector and routine
;
;***************************************;***************************************
;
LOW_INT_VECTOR	CODE	0x0018

		bra	LowInt		;go to low priority interrupt routine
;
;***************************************;***************************************
;
;	High priority interrupt routine
;
;***************************************;***************************************
;
		CODE
HighInt:
;
HighInt_Chk4TXB0:
		btfss	PIE3,	TXB0IP			; skip next if TXB0 interrupt enabled
		goto	HighInt_Chk4RXB0
;
		btfsc	PIR3,	TXB0IF			; skip next if TXB0 interrupted
		call	TXB0_INT
;
HighInt_Chk4RXB0:
		btfss	PIE3,	RXB0IP			; skip next if RXB0 interrupt enabled
		goto	HighInt_Chk4IRX
;
		btfsc	PIR3,	RXB0IF			; skip next if RXB0 interrupted
		call	RXB0_INT
;
HighInt_Chk4IRX:
		btfss	PIE3,	IRXIP			; skip next if IRX interrupt enabled
		goto	HighInt_Chk4ERR
;
		btfsc	PIR3,	IRXIF			; skip next if IRX interrupted
		call	IRX_INT
;
HighInt_Chk4ERR:
		btfss	PIE3,	ERRIP			; skip next if ERR interrupt enabled
		goto	HighInt_Exit
;
		btfsc	PIR3,	ERRIF			; skip next if ERR interrupted
		call	ERR_INT	
			
;
HighInt_Exit:
		retfie	FAST
;
;***************************************;***************************************
;
;	Low priority interrupt routine
;
;***************************************;***************************************
;
LowInt:
		movff	STATUS,STATUS_TEMP	;save STATUS register
		movff	WREG,WREG_TEMP		;save working register
		movff	BSR,BSR_TEMP		;save BSR register
;
LowInt_Chk4TMR1:
		btfss	PIE1,	TMR1IE		; skip next if TMR1 interrupt enabled
		goto	LowInt_TX
;
		btfss	PIR1,	TMR1IF		; skip next if TMR1 overflowed
		goto	LowInt_TX
;				
		call	TMR1_INT
		goto	LowInt_Exit
		
LowInt_TX:
		btfss	PIE1,	TXIE,	0	; skip next if TX interrupt is enabled
		goto	LowInt_RC
;
		btfsc	PIR1,	TXIF,	0	; skip next if TX no interrupt
		call	TX_INT		
;
LowInt_RC:
		btfss	PIE1,	RCIE,	0	; skip next if RX interrupt is enabled
		goto	LowInt_Exit
;
		btfsc	PIR1,	RCIF,		; skip next if RX no interrupt
		call	RC_INT
;
LowInt_Exit:
		movff	BSR_TEMP,BSR		;restore BSR register
		movff	WREG_TEMP,WREG		;restore working register
		movff	STATUS_TEMP,STATUS	;restore STATUS register
		retfie
;
;***************************************;***************************************
;
;	UART transmitter empty Interrupt
;
;***************************************;***************************************
;
TX_INT:
		movf	UARTOutputBufferTail,	W
		cpfseq	UARTOutputBufferHead	; skip if nothing to send
		goto	TX_INT_Character
;
TX_INT_Done:
		bcf		PIE1,	TXIE			; no more characters, stop interrupts
		goto	TX_INT_Exit
;
TX_INT_Character:
		lfsr	0,	UARTInputBuffer		; load the base
		movff	PLUSW0,	TXREG			; move @W to transmitter
;
		movff	UARTOutputBufferTail,	ITEMP
		movlw	LOW (UARTOutputBuffer+(UARTOutputBufferLength-1))	; End Of Buffer
		cpfseq	ITEMP					; skip next if UARTOutputBufferTail=EOB	
		goto	TX_INT_TailInc			; no adjustment needed
;
TX_INT_AdjustTail:
		movlw	LOW UARTOutputBuffer
		goto	TX_INT_TailOK		
;
TX_INT_TailInc:
		incf	UARTOutputBufferTail,	W
;
TX_INT_TailOK:		
		movwf	UARTOutputBufferTail	; save the Tail pointer
		btfss	TXSTA,	TRMT			; skip next if transmitter is empty
		goto	TX_INT_Exit				; done for now	
;
TX_INT_TransmitterMT:
		goto	TX_INT					; try moving another		
;
TX_INT_Exit:
		bcf		PIR1,	TXIF			; clear interrupt				
		return
;
;***************************************;***************************************
;
;	UART receive character Interrupt
;
;***************************************;***************************************
;
RC_INT:
		btfsc	RCSTA,	FERR			; skip next if no framing error
		goto	RC_INT_Error
;
		btfsc	RCSTA,	OERR			; skip next if no overrun error
		goto	RC_INT_Error
;
RC_INT_GoodCharacter:
		movff	RCREG,	ICHAR_RX		; save the incoming character
;
RC_INT_Chk4Legal_CR:		
		movlw	0x0D					; <cr>
		cpfseq	ICHAR_RX,	0			; skip next if ICHAR=<cr>
		goto	RC_INT_Chk4Legal_NUM	; not <cr>, keep checking	
;
RC_INT_CR:
		goto	RC_INT_Legal
;
RC_INT_Chk4Legal_NUM:		
		movlw	0x2F					; '/'
		cpfsgt	ICHAR_RX,	0			; skip next if ICHAR>'/'
		goto	RC_INT_Exit				; control, leave without saving
;
RC_INT_Chk4Legal_NUM_1		
		movlw	0x3A					; ':'
		cpfsgt	ICHAR_RX,	0			; skip next if ICHAR>':'
		goto	RC_INT_Legal			; must be NUMBERIC
;
RC_INT_Chk4Legal_CHAR:	
		bcf		ICHAR_RX,	5,	0		; make all upper case
;			
		movlw	0x3F					; '?'
		cpfsgt	ICHAR_RX,	0			; skip next if ICHAR>'?'
		goto	RC_INT_Exit				; punctuation, leave without saving
;
RC_INT_Chk4Legal_CHAR_1		
		movlw	0x5B    				; '['
		cpfsgt	ICHAR_RX,	0			; skip next if ICHAR>'['
		goto	RC_INT_Legal			
;
		goto	RC_INT_Exit				; punctuation, leave without saving	
;
RC_INT_Legal:
		banksel	PARAMETER9
		tstfsz	PARAMETER9,	1			; skip next if ECHO is ON
		goto	RC_INT_Legal_Chk4RCR	; else no echo
;		
		movff	ICHAR_RX,	ICHAR_TX
		call	RC_INT_Output
;
		movlw	0x0D					; was that a <cr>?
		cpfseq	ICHAR_RX,	0
		goto	RC_INT_Legal_Chk4RCR
;		
		movff	PARAMETER13,	ICHAR_TX	; <cr>
		call	RC_INT_Output
;
		banksel	PARAMETER48
		tstfsz	PARAMETER48,	1		; skip next if we want <lf>
		goto	RC_INT_Legal_Chk4RCR	; else no <lf>, then just the '>'
;		
		movff	PARAMETER10,	ICHAR_TX	; <lf>
		call	RC_INT_Output
;		
RC_INT_Legal_Chk4RCR:
		btfsc	FLAG,	RCR,	0		; skip next if command has been processed
		goto	RC_INT_Exit				; else leave without saving character
;
		movlw	0x0D					; <cr>
		cpfseq	ICHAR_RX,	0				; skip next if this is a <cr>
		goto	RC_INT_Legal_Chk4FC		; else go on
;		
		goto	RC_INT_Legal_CR			; we need to do a command
;
RC_INT_Legal_Chk4FC:
		btfsc	FLAG,	FC,	0			; skip next if the first character
		goto	RC_INT_Check4Room		; else not the first, go check if buffer full
;
RC_INT_Legal_FC:
		bsf		FLAG,	FC,	0			; set flag to indicate first character	
;
RC_INT_Legal_ClearBuffer
		movlw	LOW UARTInputBuffer
		movwf	UARTInputBufferHead
;
RC_INT_Check4Room:
		movff	UARTInputBufferHead,	ITEMP
		movlw	LOW (UARTInputBuffer+(UARTInputBufferLength-1))	; End Of Buffer
		cpfseq	ITEMP,	0				; skip next if ITEMP=EOB
		goto	RC_INT_HeadInc			; else we have room, go save to buffer
;
RC_INT_NoRoom:
		goto	RC_INT_Legal_FC			; leave without saving character
;
RC_INT_Legal_CR:
		bsf		FLAG,	RCR,	0		; set flag to indicate <cr>
		bcf		FLAG,	FC,	0			; clear flag to indicate looking for first character		
		goto	RC_INT_Exit				; leave without saving character		
;
RC_INT_HeadInc:
		incf	UARTInputBufferHead,	F,	0
		movf	ITEMP,	W,	0
		lfsr	0,	UARTInputBuffer		; load the base
		movff	ICHAR_RX,	PLUSW0		; move receiver to @W
;
		goto	RC_INT_Exit				; done here 
;
RC_INT_Error:
		bcf		RCSTA,	CREN,	0		; clear the error
		bsf		RCSTA,	CREN,	0		; reset the continuous receive bit
		goto	RC_INT_NoRoom			; and dump the character
;
RC_INT_Exit:
		bcf		PIR1,	RCIF,	0		; clear the interrupt
		return
;
;***************************************;***************************************
;
;	Timer 1 overflow Interrupt 
;
;***************************************;***************************************
;
TMR1_INT:
		movlw	HIGH T1RELOAD
		movwf	TMR1H
		movlw	LOW T1RELOAD
		movwf	TMR1L
;
		btg		FLAG1,	T1TOGGLE
;		
		decfsz	T1COUNT,	F,	0
		goto	TMR1_INT_Exit
;
		movlw	D'71'		
		movwf	T1COUNT,	0
		bsf		FLAG1,	TICK,	0		; 1 second has passed
		
TMR1_INT_Exit:			
		bcf		PIR1,	TMR1IF,	0		; clear the interrupt
		return		
;
;***************************************;***************************************
;
;	TXB0
;
;***************************************;***************************************
;
TXB0_INT:
		bcf		PIR3,	TXB0IF,	0		; clear interrupt
		return
;
;***************************************;***************************************
;
;	RXB0
;
;***************************************;***************************************
;
RXB0_INT:
		movlw	0x01
		movwf	RXSTAT,	0
		bcf		RXB0CON,	RXFUL,	0	; clear buffer
		bcf		PIR3,	RXB0IF,	0		; clear interrupt
		return
;
;***************************************;***************************************
;
;	IRX
;
;***************************************;***************************************
;
IRX_INT:
		movlw	0x02
		movwf	RXSTAT,	0				; RX IRX Error
		bcf		PIR3,	IRXIF,	0		; clear interrupt
		return
;
;***************************************;***************************************
;
;	ERR
;
;***************************************;***************************************
;
ERR_INT:
		movlw	0x03
		movwf	RXSTAT,	0				; RX ERR Error
		bcf		PIR3,	ERRIF,	0		; clear interrupt
		return
;
;***************************************;***************************************
;	
RC_INT_Output:	
RC_INT_Output_Check4Room:
		movff	UARTOutputBufferHead,	ITEMP
		movlw	LOW (UARTOutputBuffer+(UARTOutputBufferLength-1))	; End Of Buffer
		cpfseq	ITEMP					; skip next if TEMP=EOB
		goto	RC_INT_Output_HeadInc		; else no adjustment needed
;
RC_INT_Output_AdjustHead:
		movlw	LOW UARTOutputBuffer
		movwf	ITEMP
		goto	RC_INT_Output_HeadOK			
;
RC_INT_Output_HeadInc:
		incf	ITEMP,	F
;
RC_INT_Output_HeadOK:
		movf	ITEMP,	W,	0		
		cpfseq	UARTOutputBufferTail	; skip next if no room
		goto	RC_INT_Output_Room
;
RC_INT_Output_NoRoom:
		setf	WREG					; indicate unsucessful
		goto	RC_INT_Output_Exit			; and leave
;
RC_INT_Output_Room:
		movf	UARTOutputBufferHead,	W		
		lfsr	1,	UARTInputBuffer		; load the base
		movff	ICHAR_TX,	PLUSW1			; move CHAR to @W		
;
		movff	ITEMP,	UARTOutputBufferHead	; save the Head pointer
		clrf	WREG					; indicate sucess
;
		bsf		PIE1,	TXIE			; let the UART send any characters			 
		goto	RC_INT_Output_Exit			; and leave		
;
RC_INT_Output_Exit:
		return		
;
;***************************************;***************************************
;
;	Initialization
;
;***************************************;***************************************
;
Init:
Init_OSC:
		movlw	0x60					; 4MHz internal oscillator
		movwf	OSCCON
		bsf		OSCTUNE,	PLLEN		
		
Init_PORTA:
		movlw	b'11111001'				; x, x, LED7:5=1,
										; B_PLUS=0, V_SEL=0, BAT=1	
		movwf	PORTA
;		
		movlw	b'11000001'				; x, x, LED7=O, LED6:5=O,
										; B_PLUS=O, V_SEL=O, BAT=A		
		movwf	TRISA		
;
Init_PORTB:
		movlw	b'11111100'				; LED7:4=1, CAN_RX=1, CAN_TX=1, L=0, K=0	
		movwf	PORTB
;		
		movlw	b'00001000'				; LED7:4=O, CAN_RX=I, CAN_TX=O, L=O, K=O
		movwf	TRISB		
;
Init_PORTC:
		movlw	b'11111111'				; RX=1, TX=1, x, x, B_MINUS=1,
										; B_MINUS_SEN=1, K_SEN=1, B_PLUS_SEN=1	
		movwf	PORTC
;		
		movlw	b'10010111'				; RX=I, TX=O, x, x, B_MINUS=O,
										; B_MINUS_SEN=I, K_SEN=I, B_PLUS_SEN=I
		movwf	TRISC
;
Init_RAM:
		lfsr	0,	0
;
Init_RAM_Loop0:		
		clrf	POSTINC0
		tstfsz	FSR0L,	0
		goto	Init_RAM_Loop0
;
Init_RAM_Loop1:		
		clrf	POSTINC0
		tstfsz	FSR0L,	0
		goto	Init_RAM_Loop1				
;
Init_ECAN:
		movlw	b'11110000'				; Config Mode, Abort transmissions
		movwf	CANCON,	0		
;
Init_ECAN_Wait:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'10000000' 			; Interested in OPMODE bit only.
		tstfsz 	WREG 					; skip next if not config
		goto	Init_ECAN_BAUD			; else good to go
;		
		goto 	Init_ECAN_Wait 			; MSBit still zero, Continue to wait...
;
Init_ECAN_BAUD:
		movlw	b'00000100'				; SJW=1Tq, 2*(3+1) BRP=3
		movwf	BRGCON1,	0 
;
		movlw	b'10010001'				; PS2=Freely, SAM=once, PS1=3bits,
										; PT=2bits
		movwf	BRGCON2,	0
;
		movlw	b'10000001'				; Disable Wake-up, PS2=2bits
		movwf	BRGCON3,	0
;
		movlw	b'00000000'				; Operational Mode
		movwf	CANCON,	0
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		movlw	b'01000000'				; Loopback Mode for testing
;		movwf	CANCON,	0						
;				
Init_ECAN_Wait1:
;		movf 	CANSTAT, W,	0 			; Read current mode state.
;		andlw 	b'11100000' 			; Interested in OPMODE bits only.
;		xorlw	b'01000000'				; must be b'00000000'
;		tstfsz 	WREG 					; skip next if not loopback
;		goto 	Init_ECAN_Wait1 		; MSBit still zero, Continue to wait...	
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		bsf		RXB0CON,	RXM1,	0	; receive both standard and extended
;		bsf		RXB0CON,	RXM0,	0
;
Init_ECAN_MASKS:
		banksel	RXM0SIDH
;		
Init_ECAN_RXM0:							; accept all standard								
		movlw	b'00000000'				; SID10:3 or EID28:21
		movwf	RXM0SIDH,	1
		movlw	b'00000000'				; SID2:0 or EID20:16, EXIDEN=0
		movwf	RXM0SIDL,	1
		movlw	b'00000000'				; EID15:8
		movwf	RXM0EIDH,	1
		movlw	b'00000000'				; EID7:0
		movwf	RXM0EIDL,	1				
;
Init_ECAN_RXM1:							; accept all extended								
		movlw	b'00000000'				; SID10:3 or EID28:21
		movwf	RXM1SIDH,	1
		movlw	b'00001000'				; SID2:0 or EID20:16, EXIDEN=1
		movwf	RXM1SIDL,	1
		movlw	b'00000000'				; EID15:8
		movwf	RXM0EIDH,	1
		movlw	b'00000000'				; EID7:0
		movwf	RXM0EIDL,	1				
;
Init_ECAN_FILTERS:
Init_ECAN_RXF0:							; not used as mask accepts all standard								
		movlw	b'00000000'				; SID10:3 or EID28:21
		movwf	RXF0SIDH,	1
		movlw	b'00000000'				; SID2:0 or EID20:16, EXIDEN=0
		movwf	RXF0SIDL,	1
		movlw	b'00000000'				; EID15:8
		movwf	RXF0EIDH,	1
		movlw	b'00000000'				; EID7:0
		movwf	RXF0EIDL,	1		
;
Init_ECAN_RXF1:							; not used as mask accepts all extended								
		movlw	b'00000000'				; SID10:3 or EID28:21
		movwf	RXF1SIDH,	1
		movlw	b'00001000'				; SID2:0 or EID20:16, EXIDEN=1
		movwf	RXF1SIDL,	1
		movlw	b'00000000'				; EID15:8
		movwf	RXF1EIDH,	1
		movlw	b'00000000'				; EID7:0
		movwf	RXF1EIDL,	1
;
Init_ECAN_RXFCON:			
		movlw	b'00000000'				; RXF7:0 disabled
		movwf	RXFCON0,	1
		movlw	b'00000000'				; RXF15:8 disabled
		movwf	RXFCON1,	1
;
Init_ECAN_INT_Flags:					; 0=clear
		movlw	b'00000000'				; IRXIF=0, WAKIF=0, ERRIF=0, TXB1IF=0
										; TXB1IF=0, TXB0IF=0, RX1IF=0, RXB0IF=0
		movwf	PIR3,	0
;
Init_ECAN_INT_Enables:					; 1=enabled, 0=disabled
		movlw	b'00000101'				; IRXIE=0, WAKIE=0, ERRIE=0, TXB2IE=0
										; TXB1IE=0, TXB0IE=0, RX1IE=0, RXB0IE=0
		movwf	PIE3,	0
;
Init_ECAN_INT_Priorities:				; 1=high, 0=low
		movlw	b'11111111'				; IRXIP=0, WAKIP=0, ERRIP=0, TXB2IP=0
										; TXB1IP=0, TXB0IP=0, RX1IP=0, RXB0IP=0
		movwf	IPR3,	0
;
Init_ECAN_INT_TXB:
		banksel	TXBIE		
										; 1=enabled, 0=disabled (mode1 and mode2)
		movlw	b'00000100'				; x, x, x, TXB2IE=0, TXB1IE=0, TXB0IE=0, x, x
		movwf	TXBIE,	1
;
Init_ECAN_INT_B:						; 1=enabled, 0=disabled (mode1 and mode2)
		movlw	b'00000001'				; B5:0IE=0, RXB1:0IE=0
		movwf	BIE0,	1
;
		banksel	TEMP
;
Init_TMR1:
		movlw	b'10110001'
		movwf	T1CON,	0				; pre/8
		bcf		IPR1,	TMR1IP,	0		; low priority
		bsf		PIE1,	TMR1IE,	0		; enable interrupt
;
Init_TMR2:
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	D'32'		
		movwf	PR2,	0
;
Init_TMR3:
		movlw	b'10110000'
		movwf	T3CON,	0				; pre/8

;		
Init_UART:		
		movlw	b'00001000'				; BRG16=1
		movwf	BAUDCON
;
		movlw	b'10011000'				; SPEN=1, CREN=1
		movwf	RCSTA
;
		movlw	b'00100100'				; TXEN=1, BRG=1
		movwf	TXSTA				
;		
		movlw	LOW UARTRELOAD			;
		movwf	SPBRG
		movlw	HIGH UARTRELOAD
		movwf	SPBRGH
;
		bcf		PIR1,	RCIF			; clear RC flag
		bsf		PIE1,	RCIE			; enable RC interrupts
		bcf		IPR1,	RCIP			; low priority for UART RC
		bcf		IPR1,	TXIP			; low priority for UART RC		
;
Init_From_EEPROM
		clrf	EEADR 					; Data Memory Address to read
		bcf		EECON1, EEPGD,	0		; Point to DATA memory
		bcf		EECON1, CFGS,	0		; Access EEPROM
		lfsr	0,	PARAMETER0
;
From_EEPROM_Loop:
		bsf		EECON1, RD,	0			; EEPROM Read
		movff	EEDATA, POSTINC0		; PARAMETER=EEDATA
		incf	EEADR,	F,	0
		movlw	LOW (PARAMETER0+LASTPARAMETER)
		cpfsgt	FSR0L,	0
		goto	From_EEPROM_Loop		
;
Init_LF
		banksel	PARAMETER48
		clrf	PARAMETER48,	1	
;
		movff	PARAMETER51,	PROTOCOL		
;
		movlw	UARTInputBuffer
		movwf	UARTInputBufferHead
;
		movlw	UARTOutputBuffer
		movwf	UARTOutputBufferHead
		movwf	UARTOutputBufferTail
;
		movlw	PRIORITY29
		movwf	PRIORITY,	0
;
		movlw	UPPER HEADERP1
		movwf	P1HEADERU,	1
		movlw	HIGH HEADERP1
		movwf	P1HEADERH,	1		
		movlw	LOW HEADERP1
		movwf	P1HEADERL,	1		
;
		movlw	UPPER HEADERP2
		movwf	P2HEADERU,	1
		movlw	HIGH HEADERP2
		movwf	P2HEADERH,	1		
		movlw	LOW HEADERP2
		movwf	P2HEADERL,	1		
;
		movlw	UPPER HEADERP3
		movwf	P3HEADERU,	1
		movlw	HIGH HEADERP3
		movwf	P3HEADERH,	1		
		movlw	LOW HEADERP3
		movwf	P3HEADERL,	1		
;
		movlw	UPPER HEADERP4
		movwf	P4HEADERU,	1
		movlw	HIGH HEADERP4
		movwf	P4HEADERH,	1		
		movlw	LOW HEADERP4
		movwf	P4HEADERL,	1
;
		movlw	UPPER HEADERP5
		movwf	P5HEADERU,	1
		movlw	HIGH HEADERP5
		movwf	P5HEADERH,	1		
		movlw	LOW HEADERP5
		movwf	P5HEADERL,	1		
;
		movlw	UPPER HEADERP6
		movwf	P6HEADERU,	1
		movlw	HIGH HEADERP6
		movwf	P6HEADERH,	1		
		movlw	LOW HEADERP6
		movwf	P6HEADERL,	1		
;
		movlw	UPPER HEADERP7
		movwf	P7HEADERU,	1
		movlw	HIGH HEADERP7
		movwf	P7HEADERH,	1		
		movlw	LOW HEADERP7
		movwf	P7HEADERL,	1		
;
		movlw	UPPER HEADERP8
		movwf	P8HEADERU,	1
		movlw	HIGH HEADERP8
		movwf	P8HEADERH,	1		
		movlw	LOW HEADERP8
		movwf	P8HEADERL,	1		
;
		movlw	UPPER HEADERP9
		movwf	P9HEADERU,	1
		movlw	HIGH HEADERP9
		movwf	P9HEADERH,	1		
		movlw	LOW HEADERP9
		movwf	P9HEADERL,	1		
;			
		movlw	b'01011100'
		movwf	FLAG,	0
;
		bsf		FLAG1,	DISPLAYPROTOCOL,	0	; print out protocol for each request											
;
Init_INT:
		bsf		RCON,	IPEN			; enable priorities
		bsf		INTCON,	GIEH			; enable high priorities						;
		bsf		INTCON,	GIEL			; enable low priorities	
;		
Init_SignON:
		movlw	UPPER SignON
		movwf	TBLPTRU
		movlw	HIGH SignON
		movwf	TBLPTRH
		movlw	LOW SignON
		movwf	TBLPTRL
		call	DisplayMessage
;
		call	SendPrompt						
;			
		goto	Main					; go to start of main code		
;
;***************************************;***************************************
;
;	Start of main program
;
;***************************************;***************************************
;
Main:
		call	Look4Command
;
	call	Look4CANMessage
;				
		btfss	FLAG1,	TICK,	0		; skip next if 1 second has passed
		goto	MainExit
;
Main_1SecondTick:
		bcf		FLAG1,	TICK,	0
		btfsc	FLAG1,	AWAKE,	0		; skip next if no 'keep awake'
		call	KeepAwake		
;		
MainExit:
		goto	Main
;
;***************************************;***************************************
;
;	KeepAwake - Periodic 'keep awake' transmissions required to keep the
;		connection open
;
;***************************************;***************************************
;
KeepAwake:
KeepAwake_Chk4P3:
		movlw	3
		cpfseq	PROTOCOL,	0
		goto	KeepAwake_Chk4P4
;		
KeepAwakeP3_Loop:		
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP3_Loop		; else try again
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	KeepAwakeP3_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	KeepAwakeP3_Loop
;
KeepAwakeP3_Loop1:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP3_Loop		; else try again
;
		btfss	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP3_Loop1
;
KeepAwakeP3_Loop2:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP3_Loop		; else try again
;
		btfsc	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP3_Loop2
;		
		lfsr	2,	TXBBHU
		movlw	0x68
		movwf	TXBBHU,	0
		movlw	0x6A
		movwf	TXBBHH,	0
		movlw	0xF1
		movwf	TXBBHL,	0		
		movlw	0x01
		movwf	TXBBD0,	0
		movlw	0x00
		movwf	TXBBD1
		movlw	0xC4
		movwf	TXBBD2		
		movlw	6
		movwf	TEMP1,	0
;
KeepAwakeP3_Loop3:
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		tstfsz	WREG,	0				; skip next if found passive
		goto	KeepAwake				; else try again
				
		decfsz	TEMP1
		goto	KeepAwakeP3_Loop3
;
KeepAwakeP3_Try:
		call	Look4ISO
;
		tstfsz	RXCOUNT,	0			; skip next if no data found
		goto	KeepAwakeP3_TryAgain
;
KeepAwakeP3_NoReply:
		nop		;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;		goto	KeepAwakeP3_NoReply
;
KeepAwakeP3_TryAgain:
		call	Look4ISO
;
		tstfsz	RXCOUNT,	0			; skip next if no more data found
		goto	KeepAwakeP3_TryAgain
;
		goto	KeepAwake_Exit			
;
KeepAwake_Chk4P4:
		movlw	4
		cpfseq	PROTOCOL,	0
		goto	KeepAwake_Chk4P5
;		
KeepAwakeP4_Loop:		
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP4_Loop		; else try again
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	KeepAwakeP4_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	KeepAwakeP4_Loop
;
KeepAwakeP4_Loop1:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP4_Loop		; else try again
;
		btfss	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP4_Loop1
;
KeepAwakeP4_Loop2:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP4_Loop		; else try again
;
		btfsc	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP4_Loop2
;		
		lfsr	2,	TXBBHU
		movlw	0xC1
		movwf	TXBBHU,	0
		movlw	0x33
		movwf	TXBBHH,	0
		movlw	0xF1
		movwf	TXBBHL,	0		
		movlw	0x3E
		movwf	TXBBD0,	0
		movlw	0x23
		movwf	TXBBD1
		movlw	5
		movwf	TEMP1,	0
;
KeepAwakeP4_Loop3:
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		tstfsz	WREG,	0				; skip next if found passive
		goto	KeepAwake				; else try again
				
		decfsz	TEMP1
		goto	KeepAwakeP4_Loop3
;
		goto	KeepAwake_Exit		
;		
KeepAwake_Chk4P5:
		movlw	5
		cpfseq	PROTOCOL,	0
		goto	KeepAwake_Exit
;		
KeepAwakeP5_Loop:		
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP5_Loop		; else try again
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	KeepAwakeP5_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	KeepAwakeP5_Loop	
;
KeepAwakeP5_Loop1:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP5_Loop		; else try again
;
		btfss	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP5_Loop1
;
KeepAwakeP5_Loop2:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	KeepAwakeP5_Loop		; else try again
;
		btfsc	FLAG1,	T1TOGGLE,	0
		goto	KeepAwakeP5_Loop2
;		
		lfsr	2,	TXBBHU
		movlw	0xC1
		movwf	TXBBHU,	0
		movlw	0x33
		movwf	TXBBHH,	0
		movlw	0xF1
		movwf	TXBBHL,	0		
		movlw	0x3E
		movwf	TXBBD0,	0
		movlw	0x23
		movwf	TXBBD1
		movlw	5
		movwf	TEMP1,	0
;
KeepAwakeP5_Loop3:
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		tstfsz	WREG,	0				; skip next if found passive
		goto	KeepAwake				; else try again
				
		decfsz	TEMP1
		goto	KeepAwakeP5_Loop3
;
KeepAwake_Exit:		
		return							
;
;***************************************;***************************************
;
;	Check for CHAR in Input Buffer
;
;	CHAR	=	input character
;	STATE	=	number of characters
;
;***************************************;***************************************
;	
UserInput:								
		movlw	LOW UARTInputBuffer
		cpfseq	UARTInputBufferHead,	0	; skip next if no data
		goto	UserInput_GotSome
;
UserInput_None:
		clrf	STATE, 0				; no characters
		goto	UserInput_Exit
;
UserInput_GotSome:
		movf	UARTInputBufferHead,	W,	0
		lfsr	1,	UARTInputBuffer		; load the base
		movff	PLUSW1,	CHAR			; move @W to CHAR
;		
		movwf	STATE,	0				; number of characters in buffer		
;
UserInput_Exit:					
		return
;
;***************************************;***************************************
;
;	Move Character to UART Output Buffer
;
;	character in CHAR
;	leave with WREG indicating sucess status (OK=0)
;
;***************************************;***************************************
;
UserOutput:
		bcf		LATA,	LED5,	0
		bcf		INTCON,	GIEL,	0
UserOutput_Check4Room:
		movff	UARTOutputBufferHead,	TEMP
		movlw	LOW (UARTOutputBuffer+(UARTOutputBufferLength-1))	; End Of Buffer
		cpfseq	TEMP,	0				; skip next if TEMP=EOB
		goto	UserOutput_HeadInc		; else no adjustment needed
;
UserOutput_AdjustHead:
		movlw	LOW UARTOutputBuffer
		movwf	TEMP
		goto	UserOutput_HeadOK			
;
UserOutput_HeadInc:
		incf	TEMP,	F,	0
;
UserOutput_HeadOK:		
		movf	TEMP,	W,	0
		cpfseq	UARTOutputBufferTail	; skip next if no room
		goto	UserOutput_Room
;
UserOutput_NoRoom:
		setf	WREG,	0				; indicate unsucessful
;		goto	UserOutput_Exit			; and leave
		bsf		INTCON,	GIEL,	0		; give interrupts a chance
		nop
		nop
		nop
		nop
		goto	UserOutput				; Try Again
;
UserOutput_Room:
		movf	UARTOutputBufferHead,	W		
		lfsr	1,	UARTInputBuffer		; load the base
		movff	CHAR,	PLUSW1			; move CHAR to @W		
;
		movff	TEMP,	UARTOutputBufferHead	; save the Head pointer
		clrf	WREG,	0					; indicate sucess
;
		bsf		PIE1,	TXIE,	0			; let the UART send any characters			 
		goto	UserOutput_Exit			; and leave
;
UserOutput_Exit
		bsf		INTCON,	GIEL,	0
		bsf		LATA,	LED5,	0		
		return
;
;***************************************;***************************************
;
;	Send any Error Message
;
;***************************************;***************************************
;
SendErrors:
SendErrors_Chk4BFULL:
		btfss	EFLAG,	BFULL,	0		; skip next if Buffer Full error
		goto	SendErrors_Chk4BBUSY
;
SendErrors_BFULL:		
		movlw	UPPER BufferFull
		movwf	TBLPTRU
		movlw	HIGH BufferFull
		movwf	TBLPTRH
		movlw	LOW BufferFull
		movwf	TBLPTRL
		call	DisplayMessage		
;		
		bcf		EFLAG,	BFULL,	0
;
SendErrors_Chk4BBUSY:
		btfss	EFLAG,	BBUSY,	0		; skip next if Bus Busy error
		goto	SendErrors_Chk4DERROR
;
SendErrors_BBUSY:		
		movlw	UPPER BusBusy
		movwf	TBLPTRU
		movlw	HIGH BusBusy
		movwf	TBLPTRH
		movlw	LOW BusBusy
		movwf	TBLPTRL
		call	DisplayMessage		
;		
		bcf		EFLAG,	BBUSY,	0
;
SendErrors_Chk4DERROR:
		btfss	EFLAG,	DERROR,	0		; skip next if Data Error
		goto	SendErrors_Chk4NDATA
;
SendErrors_DERROR:		
		movlw	UPPER DataError
		movwf	TBLPTRU
		movlw	HIGH DataError
		movwf	TBLPTRH
		movlw	LOW DataError
		movwf	TBLPTRL
		call	DisplayMessage		
;		
		bcf		EFLAG,	DERROR,	0
;
SendErrors_Chk4NDATA:
		btfss	EFLAG,	NDATA,	0		; skip next if NoData error
		goto	SendErrors_Chk4UCONNECT		
;
SendErrors_NDATA:		
		movlw	UPPER NoData
		movwf	TBLPTRU
		movlw	HIGH NoData
		movwf	TBLPTRH
		movlw	LOW NoData
		movwf	TBLPTRL
		call	DisplayMessage		
;		
		bcf		EFLAG,	NDATA,	0
;
SendErrors_Chk4UCONNECT:
		btfss	EFLAG,	UCONNECT,	0		; skip next if NoData error
		goto	SendErrors_Chk4QMARK		
;
SendErrors_UCONNECT:		
		movlw	UPPER UnableToConnect
		movwf	TBLPTRU
		movlw	HIGH UnableToConnect
		movwf	TBLPTRH
		movlw	LOW UnableToConnect
		movwf	TBLPTRL
		call	DisplayMessage		
;		
		bcf		EFLAG,	UCONNECT,	0		
;
SendErrors_Chk4QMARK:
		btfss	EFLAG,	QMARK,	0		; skip next if '?' error
		goto	SendQuestionMark_Exit		
;
SendErrors_QMARK:		
		movlw	a'?'					; '?'
		movwf	CHAR,	0
		call	UserOutput
;
		call	SendCR			
;		
		bcf		EFLAG,	QMARK,	0		
;
SendQuestionMark_Exit:
		return
;
;***************************************;***************************************
;
;	Send a 'OK'
;
;***************************************;***************************************
;
SendOK:
		movlw	a'O'					; 'O'
		movwf	CHAR,	0
		call	UserOutput
;
		movlw	a'K'					; 'K'
		movwf	CHAR,	0
		call	UserOutput		
;
		call	SendCR
;
SendOK_Exit:
		return		
;
;***************************************;***************************************
;
;	Send a '>'
;
;***************************************;***************************************
;
SendPrompt:
		movlw	a'>'					; '>'
		movwf	CHAR,	0
		call	UserOutput
;
SendPrompt_Exit:
		return	
;
;***************************************;***************************************
;
;	Send a <cr> (and potential <lf>
;
;***************************************;***************************************
;
SendCR:
		movff	PARAMETER13,	CHAR	;<cr>
		call	UserOutput
;
		banksel	PARAMETER48
		tstfsz	PARAMETER48,	1		; skip next if we want <lf>
		goto	SendCR_Exit				; else no <lf>, then just the '>'
;		
		movff	PARAMETER10,	CHAR	; <lf>
		call	UserOutput		
;
SendCR_Exit:
		return				
;
;***************************************;***************************************
;
;	Look For a Command
;
;***************************************;***************************************
;
Look4Command:
		btfss	FLAG,	RCR,	0		; skip next if we need to do a command

		goto	Look4Command_Exit		; else nothing to do	
;
		call	UserInput
;
;***************************************
;
Look4AT:
		lfsr	1,	UARTInputBuffer		; start of buffer
;		
Look4AT_Chk4A:		
		movlw	a'A'
		cpfseq	POSTINC1
		goto	Look4Data				; might be data
;
Look4AT_Chk4AT:		 
		movlw	a'T'
		cpfseq	POSTINC1
		goto	Look4Data				; might be data
;
MightBeCommand:
;
Look4State3:
		movlw	0x03
		cpfseq	STATE,	0				; skip next if State=3
		goto	Look4State4				; else look for State 4
;
State3:
		goto	Look4StateEOL			; no such command				
;
;***************************************
;
Look4State4:
		movlw	0x04
		cpfseq	STATE,	0				; skip next if State=4
		goto	Look4State5				; else look for State 5
;
State4_Chk4ATD:
		movlw	a'D'
		cpfseq	INDF1
		goto	State4_Chk4ATE			; look for other commands
;
State4_Chk4ATDP:
		movlw	a'P'
		cpfseq	PREINC1
		goto	Look4StateEOL			; no such command
;
State4_ATDP_Chk4_0:
		movlw	0
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=0
		goto	State4_ATDP_Chk4_1
;
State4_ATDP0:
		movlw	UPPER P0
		movwf	TBLPTRU
		movlw	HIGH P0
		movwf	TBLPTRH
		movlw	LOW P0
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_1:
		movlw	1
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=1
		goto	State4_ATDP_Chk4_2
;
State4_ATDP1:
		movlw	UPPER P1
		movwf	TBLPTRU
		movlw	HIGH P1
		movwf	TBLPTRH
		movlw	LOW  P1
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_2:
		movlw	2
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=2
		goto	State4_ATDP_Chk4_3
;
State4_ATDP2:
		movlw	UPPER  P2
		movwf	TBLPTRU
		movlw	HIGH P2
		movwf	TBLPTRH
		movlw	LOW P2
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_3:
		movlw	3
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=3
		goto	State4_ATDP_Chk4_4
;
State4_ATDP3:
		movlw	UPPER P3
		movwf	TBLPTRU
		movlw	HIGH P3
		movwf	TBLPTRH
		movlw	LOW P3
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_4:
		movlw	4
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=4
		goto	State4_ATDP_Chk4_5
;
State4_ATDP4:
		movlw	UPPER P4
		movwf	TBLPTRU
		movlw	HIGH P4
		movwf	TBLPTRH
		movlw	LOW P4
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_5:
		movlw	5
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=5
		goto	State4_ATDP_Chk4_6
;
State4_ATDP5:
		movlw	UPPER P5
		movwf	TBLPTRU
		movlw	HIGH P5
		movwf	TBLPTRH
		movlw	LOW P5
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_6:
		movlw	6
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=6
		goto	State4_ATDP_Chk4_7
;
State4_ATDP6:
		movlw	UPPER P6
		movwf	TBLPTRU
		movlw	HIGH P6
		movwf	TBLPTRH
		movlw	LOW P6
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_7:
		movlw	7
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=7
		goto	State4_ATDP_Chk4_8
;
State4_ATDP7:
		movlw	UPPER P7
		movwf	TBLPTRU
		movlw	HIGH P7
		movwf	TBLPTRH
		movlw	LOW P7
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_8:
		movlw	8
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=8
		goto	State4_ATDP_Chk4_9
;
State4_ATDP8:
		movlw	UPPER P8
		movwf	TBLPTRU
		movlw	HIGH P8
		movwf	TBLPTRH
		movlw	LOW P8
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_9:
		movlw	9
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=9
		goto	State4_ATDP_Chk4_10
;
State4_ATDP9:
		movlw	UPPER P9
		movwf	TBLPTRU
		movlw	HIGH P9
		movwf	TBLPTRH
		movlw	LOW P9
		movwf	TBLPTRL
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_10:
		movlw	d'10'
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=10
		goto	State4_ATDP_Chk4_11
;
State4_ATDP10:
		movlw	UPPER DF2
		movwf	TBLPTRU
		movlw	HIGH DF2
		movwf	TBLPTRH
		movlw	LOW DF2
		movwf	TBLPTRL
		call	DisplayMessageNOCR		
;	
		movlw	UPPER BAUD50
		movwf	TBLPTRU
		movlw	HIGH BAUD50
		movwf	TBLPTRH
		movlw	LOW BAUD50
		movwf	TBLPTRL
;				
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_11:
		movlw	d'11'
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=11
		goto	State4_ATDP_Chk4_12
;
State4_ATDP11:
		movlw	UPPER DF0
		movwf	TBLPTRU
		movlw	HIGH DF0
		movwf	TBLPTRH
		movlw	LOW DF0
		movwf	TBLPTRL
		call	DisplayMessageNOCR		
;	
		movlw	UPPER BAUD125
		movwf	TBLPTRU
		movlw	HIGH BAUD125
		movwf	TBLPTRH
		movlw	LOW BAUD125
		movwf	TBLPTRL		
;		
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_12:
		movlw	d'12'
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=12
		goto	State4_ATDP_Chk4_13
;
State4_ATDP12:
		movlw	UPPER DF0
		movwf	TBLPTRU
		movlw	HIGH DF0
		movwf	TBLPTRH
		movlw	LOW DF0
		movwf	TBLPTRL
		call	DisplayMessageNOCR		
;	
		movlw	UPPER BAUD50
		movwf	TBLPTRU
		movlw	HIGH BAUD50
		movwf	TBLPTRH
		movlw	LOW BAUD50
		movwf	TBLPTRL		
		goto	State4_ATDP_Display		; go display message
;
State4_ATDP_Chk4_13:
		goto	Look4StateEOL			; no such command
;
State4_ATDP_Display:		
		call	DisplayMessage
;
		call	SendPrompt
;		
		goto	Look4State_FinishedCommand	; done here			
;
;*******************
;
State4_Chk4ATE:
		movlw	a'E'
		cpfseq	INDF1
		goto	State4_Chk4ATF			; look for other commands
;
State4_Chk4ATE0:
		movlw	a'0'
		cpfseq	PREINC1
		goto	State4_Chk4ATE1			; look for other values				
;
State4_ATE0:							; OFF
		banksel	PARAMETER9
		setf	PARAMETER9,	1			; linefeeds OFF
		goto	Look4State_FinishedCommand	; done here
;
State4_Chk4ATE1:
		movlw	a'1'
		cpfseq	INDF1
		goto	Look4StateEOL			; no such command
;
State4_ATE1:							; ON
		banksel	PARAMETER9
		clrf	PARAMETER9,	1			; linefeeds ON
		goto	Look4State_FinishedCommand	; done here
;
;*******************
;
State4_Chk4ATF:
		movlw	a'F'
		cpfseq	INDF1
		goto	State4_Chk4ATH			; look for other commands
;
State4_Chk4ATFI:
		movlw	a'I'
		cpfseq	PREINC1
		goto	Look4StateEOL			; no such command
;
State4_ATFI:							; request slow init
		movlw	5
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=5
		goto	Look4StateEOL			; no such command
;		
		call	Wakeup				
;
;*******************
;
State4_Chk4ATH:
		movlw	a'H'
		cpfseq	INDF1
		goto	State4_Chk4ATL			; look for other commands
;
State4_Chk4ATH0:
		movlw	a'0'
		cpfseq	PREINC1
		goto	State4_Chk4ATH1			; look for other values				
;
State4_ATH0:							; OFF
		bcf		FLAG,	HF,	0			; headers OFF
		goto	Look4State_FinishedCommand	; done here
;
State4_Chk4ATH1:
		movlw	a'1'
		cpfseq	INDF1
		goto	Look4StateEOL			; no such command
;
State4_ATH1:							; ON
		bsf		FLAG,	HF,	0			; headers ON
		goto	Look4State_FinishedCommand	; done here		
;
;*******************
;
State4_Chk4ATL:
		movlw	a'L'
		cpfseq	INDF1
		goto	State4_Chk4ATS			; look for other commands
;
State4_Chk4ATL0:
		movlw	a'0'
		cpfseq	PREINC1
		goto	State4_Chk4ATL1			; look for other values				
;
State4_ATL0:							; OFF
		banksel	PARAMETER48
		setf	PARAMETER48,	1			; linefeeds OFF
		goto	Look4State_FinishedCommand	; done here
;
State4_Chk4ATL1:
		movlw	a'1'
		cpfseq	INDF1
		goto	Look4StateEOL			; no such command
;
State4_ATL1:							; ON
		banksel	PARAMETER48
		clrf	PARAMETER48,	1		; linefeeds ON
		goto	Look4State_FinishedCommand	; done here	
;
;*******************
;
State4_Chk4ATS:
		movlw	a'S'
		cpfseq	INDF1
		goto	State4_Chk4AT_			; look for other commands
;
State4_Chk4ATS0:
		movlw	a'0'
		cpfseq	PREINC1
		goto	State4_Chk4ATS1			; look for other values				
;
State4_ATS0:							; OFF
		bcf		FLAG,	SF,	0			; spaces OFF
		goto	Look4State_FinishedCommand	; done here
;
State4_Chk4ATS1:
		movlw	a'1'
		cpfseq	INDF1
		goto	State4_Chk4ATSI			; look for other values	
;
State4_ATS1:							; ON
		bsf		FLAG,	SF,	0			; spaces ON
		goto	Look4State_FinishedCommand	; done here	
;
State4_Chk4ATSI:
		movlw	a'I'
		cpfseq	INDF1
		goto	Look4StateEOL			; no such command
;
State4_ATSI:							; request slow init
		movlw	2
		cpfsgt	PROTOCOL,	0			; skip next if PROTOCOL>2
		goto	Look4StateEOL			; no such command
;		
		movlw	5
		cpfslt	PROTOCOL,	0			; skip next if PROTOCOL<5
		goto	Look4StateEOL			; no such command		
;		
		call	Wakeup
;		
		goto	Look4State_FinishedCommand	; done here								
;
;*******************
;
State4_Chk4AT_:
		goto	Look4StateEOL			; no such command	
;
;***************************************
;
Look4State5:
		movlw	0x05
		cpfseq	STATE,	0				; skip next if State=5
		goto	Look4State6				; else look for State 6
;
State5_Chk4ATD:
		movlw	a'D'
		cpfseq	INDF1
		goto	State5_Chk4ATT			; look for other commands
;
State5_Chk4ATDP:
		movlw	a'P'
		cpfseq	PREINC1
		goto	Look4StateEOL			; no such command
;
State5_Chk4ATDPN:
		movlw	a'N'
		cpfseq	PREINC1
		goto	Look4StateEOL			; no such command		
;
State5_ATDPN:
		movff	PROTOCOL,	CHAR
		movlw	0x09
		cpfsgt	CHAR,	0				; skip next if CHAR>9
		goto	State5_ATDPN_
;
		movlw	0x07
		addwf	CHAR,	F,	0
;
State5_ATDPN_:
		movlw	0x30
		addwf	CHAR,	F,	0
		call	UserOutput				
;	
		goto	Look4State_FinishedCommand	; done here						
;
;*******************
;
State5_Chk4ATT:
		movlw	a'T'
		cpfseq	INDF1
		goto	State5_Chk4AT_			; look for other commands
;		
State5_Chk4ATTP:
		movlw	a'P'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;
State5_ATTPh:							; value
		bcf		FLAG,	AF,	0			; clear auto flag
		movff	PREINC1,	VALUE
		call	GetValue
;
		tstfsz	WREG,	0				; skip next if VALUE=0-15
		goto	Look4StateEOL			; no such command
;
		movff	PARAMETER7,	WREG
		cpfsgt	VALUE,	0				; skip next if VALUE>PARAMETER7
		goto	State5_ATTPh_OK
;		
		goto	Look4StateEOL			; no such command
;
State5_ATTPh_OK:
		movff	VALUE,	PROTOCOL
		goto	Look4State_FinishedCommand	; done here				
;
;*******************
;		
State5_Chk4AT_:
		goto	Look4StateEOL			; no such command
;
;***************************************
;
Look4State6:
		movlw	0x06
		cpfseq	STATE,	0				; skip next if State=6
		goto	Look4State7				; else look for State 7
;
;*******************
;
State6_Chk4ATC:
		movlw	a'C'
		cpfseq	INDF1
		goto	State6_Chk4ATT			; look for other commands
;		
State6_Chk4ATCA:
		movlw	a'A'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;		
State6_Chk4ATCAF:
		movlw	a'F'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;		
State6_Chk4ATCA0:
		movlw	a'0'
		cpfseq	PREINC1
		goto	State6_Chk4ATCA1		; look for other values				
;
State6_ATCA0:							; OFF
		bcf		FLAG,	CAFF,	0		; auto formatting OFF
		goto	Look4State_FinishedCommand	; done here
;
State6_Chk4ATCA1:
		movlw	a'1'
		cpfseq	INDF1
		goto	Look4StateEOL			; no such command
;
State6_ATCA1:							; ON
		bsf		FLAG,	CAFF,	0		; auto formatting  ON
		goto	Look4State_FinishedCommand	; done here			
;
;*******************
;
State6_Chk4ATT:
		movlw	a'T'
		cpfseq	INDF1
		goto	State6_Chk4AT_			; look for other commands
;		
State6_Chk4ATTP:
		movlw	a'P'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;		
State6_Chk4ATTPA:
		movlw	a'A'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;		
State6_ATTPAh:							; value
		movff	PREINC1,	VALUE
		call	GetValue
;
		movff	VALUE,	PROTOCOL
		bsf		FLAG,	AF,	0			; set auto scan for protocol
		goto	Look4State_FinishedCommand	; done here	
;
;*******************
;
State6_Chk4AT_:	
		goto	Look4StateEOL			; no such command		
;
;***************************************
;
Look4State7:
		movlw	0x07
		cpfseq	STATE,	0				; skip next if State=7
		goto	Look4State8				; else look for State 8
;
State7_Chk4ATS:
		movlw	a'S'
		cpfseq	INDF1,	0
		goto	Look4StateEOL			; no such command
;
State7_Chk4ATSH:
		movlw	a'H'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;
State7_Chk4ATSHh:
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		movff	VALUE,	THEADERH
		movwf	THEADERU,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		swapf	VALUE,	W
		movwf	THEADERL,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		movf	VALUE,	W,	0
		iorwf	THEADERL,	0
		movff	THEADERL,	HEADERL
		movff	THEADERL,	HEADERL		
		clrf	HEADERU,	0		
		goto	Look4State_FinishedCommand	; done here	
;
;***************************************
;
Look4State8:
		movlw	0x08
		cpfseq	STATE,	0				; skip next if State=8
		goto	Look4State9				; else look for State 9
;
State8:
		goto	Look4StateEOL			; no such command		
;
;***************************************
;
Look4State9:
		movlw	0x09
		cpfseq	STATE,	0				; skip next if State=9
		goto	Look4State10			; else look for State 10
;
State9:
		goto	Look4StateEOL			; no such command
;
;***************************************
;
Look4State10:
		movlw	0x0A
		cpfseq	STATE,	0				; skip next if State=10
		goto	Look4State11			; else look for State 11
;
State10_Chk4ATS:
		movlw	a'S'
		cpfseq	INDF1,	0
		goto	Look4StateEOL			; no such command
;
State10_Chk4ATSH:
		movlw	a'H'
		cpfseq	PREINC1,	0
		goto	Look4StateEOL			; no such command
;
State10_Chk4ATSHh:
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		swapf	VALUE,	W,	0
		movwf	THEADERU,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		movf	VALUE,	W,	0
		iorwf	THEADERU,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		swapf	VALUE,	W,	0
		movwf	THEADERH,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		movf	VALUE,	W,	0
		iorwf	THEADERH,	0		
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		swapf	VALUE,	W,	0
		movwf	THEADERL,	0
		movff	PREINC1,	VALUE
		call	GetValue
;
		btfss	STATUS,	Z,	0			; skip if no error		
		goto	Look4StateEOL			; no such command
;	
		movf	VALUE,	W,	0
		iorwf	THEADERL,	0		
		movff	THEADERL,	HEADERL
		movff	THEADERH,	HEADERH		
		movff	THEADERU,	HEADERU	
		goto	Look4State_FinishedCommand	; done here		
;
;***************************************
;
Look4State11:
		movlw	0x0B
		cpfseq	STATE,	0				; skip next if State=11
		goto	Look4State12			; else look for State 12
;
State11:
		goto	Look4StateEOL			; no such command		
;
;***************************************
;
Look4State12:
		movlw	0x0B
		cpfseq	STATE,	0				; skip next if State=12
		goto	Look4StateEOL			; else no such command
;
State12:
		goto	Look4StateEOL			; no such command	
;
;***************************************
;
Look4Data:
		lfsr	1,	UARTInputBuffer		; start of buffer
		lfsr	2,	TXBYTE0		
		clrf	PCI,	0
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	Look4Data_Loop			; no formatting
;
Look4Data_AF:
		lfsr	2,	TXBYTE1
;
Look4Data_Loop:
		tstfsz	STATE,	0				; skip next if STATE=0
		goto	Look4Data_1
;
Look4Data0:								; no characters left
		goto	Look4Data_Done		
;
Look4Data_1:		
		movlw	D'1'
		cpfsgt	STATE					; skip next if STATE>1
		goto	Look4StateEOL			; else characters are not in pairs, error
;
Look4Data1:								; at least 2 characters 
		movff	POSTINC1,	VALUE		; 1st character
		call	GetValue				; get its value
		tstfsz	WREG					; skip next if WREG=0 (OK)
		goto	Look4StateEOL			; error
;
		swapf	VALUE,	W,	0
		movwf	TEMP,	0
		movff	POSTINC1,	VALUE		; 2nd character
		call	GetValue				; get its value
		tstfsz	WREG					; skip next if WREG=0 (OK)
		goto	Look4StateEOL			; error
;
		movf	VALUE,	W,	0
		iorwf	TEMP,	W,	0
		movwf	POSTINC2,	0			; save byte value as TXBYTE(data)
		incf	PCI,	F,	0
;
		decf	STATE,	F,	0
		decf	STATE,	F,	0
		movlw	D'8'
		cpfseq	PCI,	0				; skip next if BYTECOUNT<8
		goto	Look4Data_Loop
;
		goto	Look4StateEOL			; error			
;
Look4Data_Done:
		tstfsz	PCI,	0				; skip next if no data to send
		goto	Look4Data_OK
;
		goto	Look4StateEOL			; error
;
Look4Data_OK:							; we've got data to send
		bcf		FLAG,	AUTOINPROCESS,	0
;
Look4Data_OK_Loop:			
		movff	PARAMETER7,	WREG		; max protocol		
		cpfsgt	PROTOCOL,	0			; skip next if PROTOCOL>max protocol
		goto	Look4Data_OK_Send
;
		goto	Look4Data_Abort				
;
Look4Data_OK_NextProtocol:
		btfsc	FLAG,	AUTOINPROCESS,	0	; skip next if haven't done auto 
		goto	Look4Data_OK_Continue	
;
		btfss	FLAG,	AF,	0			; skip next if auto mode
		goto	Look4Data_Abort	
;		
		movff	PROTOCOL,	TPROTOCOL	; save this protocol
		movlw	1
		movwf	PROTOCOL,	0
		bsf		FLAG,	AUTOINPROCESS,	0
		goto	Look4Data_OK_Loop	
;		
Look4Data_OK_Continue:
		incf	PROTOCOL,	F,	0
		goto	Look4Data_OK_Loop
;
Look4Data_OK_Send:
		call	TransmitRequest
;		
		tstfsz	WREG,	0				; skip next if successful
		goto	Look4Data_OK_NextProtocol	; else unsucessful, more?	
;
		goto	Look4State_FinishedCommand
;
Look4Data_Abort:
		movff	TPROTOCOL,	PROTOCOL	; get back original
		banksel	TXB0CON
		bcf		TXB0CON,	TXREQ,	0	; abort try
		bsf		EFLAG,	UCONNECT,	0
		call	SendErrors
;
		goto	Look4State_FinishedCommand		
;
;***************************************
;
Look4StateEOL:							; we've reached the end of the line
		bcf		FLAG,	RCR,	0		; clear the flag indicating no command to do
		bsf		EFLAG,	QMARK
		call	SendErrors
;		
		goto	Look4Command_Exit	
;
Look4State_FinishedCommand:
		bcf		FLAG,	RCR,	0		; clear the flag indicating no command to do
		call	SendOK
;		
		call	SendPrompt			
;
Look4Command_Exit:		
		return
;
;***************************************;***************************************
;
;	Look for a Received Message 
;
;***************************************;***************************************
;
Look4CANMessage:
		movlw	0
		cpfsgt	RXSTAT,	0
		goto	Look4CANMessage_Exit
;
Look4_Chk4RXSTAT1:
		movlw	1
		cpfseq	RXSTAT,	0
		goto	Look4_Chk4RXSTAT2
;
Look4_RXSTAT1:
		lfsr	2,	RXB0D7
		call	DisplayRegisterBank	
;
		call	SendPrompt
;
Look4_Chk4RXSTAT2:
		movlw	1
		cpfseq	RXSTAT,	0
		goto	Look4_Chk4RXSTAT3
;
Look4_RXSTAT2:
;
Look4_Chk4RXSTAT3:
		movlw	1
		cpfseq	RXSTAT,	0
		goto	Look4CANMessage_Done
;
Look4_RXSTAT3:
;
Look4CANMessage_Done
		clrf	RXSTAT		
;
Look4CANMessage_Exit:		
		return	
;
;***************************************;***************************************
;
;	Transmit Request using present value in PROTOCOL
;
;	WREG returns 0=success, 1=failure
;
;***************************************;***************************************
;
TransmitRequest:
;
TransmitRequest_Chk4_gtmax:
		movff	PARAMETER7,	WREG		; max protocol		
		cpfsgt	PROTOCOL,	0				; skip next if PROTOCOL>max protocol
		goto	TransmitRequest_Chk4_1
;
TransmitRequest_gtmax:
		goto	TransmitRequest_Error		
;		
TransmitRequest_Chk4_1:
		movlw	1
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=1
		goto	TransmitRequest_Chk4_2		
;
TransmitRequest_1:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_1_Continue	; branch if protocol already set
;		
		call	SetProtocol_1
;
TransmitRequest_1_Continue:		
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next to display protocol 
		goto	TransmitRequest_1_Continue1
;			
		movlw	UPPER P1
		movwf	TBLPTRU
		movlw	HIGH P1
		movwf	TBLPTRH
		movlw	LOW P1
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_1_Continue1:
		call	PWMTransmit
;
		call	Look4PWM
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	TransmitRequest_1_GotOne
;
TransmitRequest_1_NoData:	
		bsf		EFLAG,	NDATA,	0		; No Data Error	
		goto	TransmitRequest_Error
;
TransmitRequest_1_GotOne:
		call    DisplayResponse
;
		clrf	WREG,	0				; No Error		
		goto	TransmitRequest_Exit
;		
TransmitRequest_Chk4_2:
		movlw	2
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=2
		goto	TransmitRequest_Chk4_3		
;
TransmitRequest_2:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_2_Continue	; branch if protocol already set
;		
		call	SetProtocol_2
;
TransmitRequest_2_Continue:		
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_2_Continue1
;			
		movlw	UPPER P2
		movwf	TBLPTRU
		movlw	HIGH P2
		movwf	TBLPTRH
		movlw	LOW P2
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_2_Continue1:
		call	VPWTransmit
;
		call	Look4VPW
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	TransmitRequest_2_GotOne
;		
		bsf		EFLAG,	NDATA,	0		; No Data Error	
		goto	TransmitRequest_Error
;
TransmitRequest_2_GotOne:
		call    DisplayResponse
;
		clrf	WREG,	0				; No Error		
		goto	TransmitRequest_Exit		
;		
TransmitRequest_Chk4_3:
		movlw	3
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=3
		goto	TransmitRequest_Chk4_4		
;
TransmitRequest_3:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_3_Continue	; branch if protocol already set
;		
		call	SetProtocol_3
;
TransmitRequest_3_Continue:		
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next to display protocol
		goto	TransmitRequest_3_Continue1
;			
		movlw	UPPER P3
		movwf	TBLPTRU
		movlw	HIGH P3
		movwf	TBLPTRH
		movlw	LOW P3
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_3_Continue1:
		btfsc	FLAG1,	AWAKE,	0		; skip next if auto polling is NOT running
		goto	TransmitRequest_3_Continue2
;
		call	Wakeup
;
		tstfsz	WREG,	0
		goto	TransmitRequest_3_NotAwake
;
TransmitRequest_3_Continue2:
		movff	P3HEADERU,	HEADERU
		movff	P3HEADERH,	HEADERH
		movff	P3HEADERL,	HEADERL
		call	ISOTransmit
;
		tstfsz	WREG,	0
		goto	TransmitRequest_Error
;
TransmitRequest_3_Try:
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		movlw	1						; 5mS
		movwf	TEMP						
		call	T3Wait
;		
		call	Look4ISO
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	TransmitRequest_3_Continue3
;
TransmitRequest_3_NoData:	
		bsf		EFLAG,	NDATA,	0		; No Data Error	
		goto	TransmitRequest_Error
;
TransmitRequest_3_NotAwake		
		bsf		EFLAG,	NDATA,	0		; No Data Error			
		goto	TransmitRequest_Error		
;
TransmitRequest_3_Continue3:
		call    DisplayResponse
;
		clrf	WREG,	0				; No Error
		goto	TransmitRequest_Exit		
;		
TransmitRequest_Chk4_4:
		movlw	4
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=4
		goto	TransmitRequest_Chk4_5		
;
TransmitRequest_4:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_4_Continue	; branch if protocol already set
;		
		call	SetProtocol_4
;
TransmitRequest_4_Continue:		
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_4_Continue1
;			
		movlw	UPPER P4
		movwf	TBLPTRU
		movlw	HIGH P4
		movwf	TBLPTRH
		movlw	LOW P4
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_4_Continue1:
		btfsc	FLAG1,	AWAKE,	0		; skip next if auto polling is NOT running
		goto	TransmitRequest_4_Continue2
;		
		call	Wakeup
;
		tstfsz	WREG,	0
		goto	TransmitRequest_4_NotAwake
;
TransmitRequest_4_Continue2:
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		movlw	1						; 5mS
		movwf	TEMP						
		call	T3Wait
;		
		movff	P4HEADERU,	HEADERU
		movff	P4HEADERH,	HEADERH
		movff	P4HEADERL,	HEADERL
		call	ISOTransmit
;
		tstfsz	WREG,	0
		goto	TransmitRequest_Error
;
TransmitRequest_4_Try:
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		movlw	1						; 5mS
		movwf	TEMP						
		call	T3Wait
;		
		call	Look4ISO
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	TransmitRequest_4_Continue3
;
TransmitRequest_4_NoData:
		bsf		EFLAG,	NDATA,	0		; No Data Error			
		goto	TransmitRequest_Error
;
TransmitRequest_4_NotAwake:	
		bsf		EFLAG,	NDATA,	0		; No Data Error			
		goto	TransmitRequest_Error		
;
TransmitRequest_4_Continue3:
		call    DisplayResponse
;		
		clrf	WREG,	0				; No Error
		goto	TransmitRequest_Exit
;		
TransmitRequest_Chk4_5:
		movlw	5
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=5
		goto	TransmitRequest_Chk4_6		
;
TransmitRequest_5:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_5_Continue	; branch if protocol already set
;		
		call	SetProtocol_5
;
TransmitRequest_5_Continue:		
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_5_Continue1
;			
		movlw	UPPER P5
		movwf	TBLPTRU
		movlw	HIGH P5
		movwf	TBLPTRH
		movlw	LOW P5
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_5_Continue1:
		btfsc	FLAG1,	AWAKE,	0		; skip next if auto polling is NOT running
		goto	TransmitRequest_5_Continue2
;		
		call	Wakeup
;
		tstfsz	WREG,	0
		goto	TransmitRequest_4_NotAwake
;
TransmitRequest_5_Continue2:
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		movlw	1						; 5mS
		movwf	TEMP						
		call	T3Wait
;		
		movff	P5HEADERU,	HEADERU
		movff	P5HEADERH,	HEADERH
		movff	P5HEADERL,	HEADERL
		call	ISOTransmit
;
		tstfsz	WREG,	0
		goto	TransmitRequest_Error
;
TransmitRequest_5_Try:
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		movlw	1						; 5mS
		movwf	TEMP						
		call	T3Wait
;		
		call	Look4ISO
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	TransmitRequest_5_Continue3
;
TransmitRequest_5_NoData:
		bsf		EFLAG,	NDATA,	0		; No Data Error		
		goto	TransmitRequest_Error
;
TransmitRequest_5_NotAwake:		
		bsf		EFLAG,	NDATA,	0		; No Data Error			
		goto	TransmitRequest_Error		
;
TransmitRequest_5_Continue3:
		call    DisplayResponse
;		
		clrf	WREG,	0				; No Error
		goto	TransmitRequest_Exit
;		
TransmitRequest_Chk4_6:
		movlw	6
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=6
		goto	TransmitRequest_Chk4_7		
;
TransmitRequest_6:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_6_Continue	; branch if protocol already set
;		
		call	SetProtocol_6
;
TransmitRequest_6_Continue:		
		movlw	RetryCount
		movwf	RETRY,	0
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_6_Continue1
;			
		movlw	UPPER P6
		movwf	TBLPTRU
		movlw	HIGH P6
		movwf	TBLPTRH
		movlw	LOW P6
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_6_Continue1:
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	TransmitRequest_6_Continue2
;
TransmitRequest_6_UseCAFF		
		movff	PCI,	TXBYTE0	
;
TransmitRequest_6_Continue2:		
		lfsr	2,	TXB0D7		
		call	CANTransmit
;
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_50MS			; 50mS 
		movwf	TMR3H,	0
		movlw	LOW T3_50MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow		
;
TransmitRequest_6_Wait:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_6_ArbitrationError
;
		btfsc	INDF2,	TXREQ,	0		; skip next if transmitted
		goto	TransmitRequest_6_Wait					
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_6_Wait1:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_6_NoDataError
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_6_Got1	
;		
		goto	TransmitRequest_6_Wait1
;
TransmitRequest_6_Got1:
		lfsr	2,	RXB0D7				; point to the receive buffer
		call	DisplayRegisterBank		; display received packet
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_6_Wait2:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_6_NoMoreData
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_6_Got1
;		
		goto	TransmitRequest_6_Wait2
;
TransmitRequest_6_NoMoreData:		
		clrf	WREG
		goto	TransmitRequest_Exit
;		
TransmitRequest_6_NoDataError:
		decfsz	RETRY,	F,	0
		goto	TransmitRequest_6_Continue1
;
		bsf		EFLAG,	NDATA,	0		; No Data Error
		goto	TransmitRequest_Error		
;
TransmitRequest_6_ArbitrationError:
		bsf		EFLAG,	BBUSY,	0		; Bus Busy Error
		goto	TransmitRequest_Error
;		
TransmitRequest_Chk4_7:
		movlw	7
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=7
		goto	TransmitRequest_Chk4_8		
;
TransmitRequest_7:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_7_Continue	; branch if protocol already set
;		
		call	SetProtocol_7
;
TransmitRequest_7_Continue:		
		movlw	RetryCount
		movwf	RETRY,	0
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_7_Continue1
;			
		movlw	UPPER P7
		movwf	TBLPTRU
		movlw	HIGH P7
		movwf	TBLPTRH
		movlw	LOW P7
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand
;
TransmitRequest_7_Continue1:
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	TransmitRequest_7_Continue2
;
TransmitRequest_7_UseCAFF		
		movff	PCI,	TXBYTE0	
;
TransmitRequest_7_Continue2:	
		lfsr	2,	TXB0D7		
		call	CANTransmit
;
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_50MS			; 50mS 
		movwf	TMR3H,	0
		movlw	LOW T3_50MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow		
;		
TransmitRequest_7_Wait:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_7_ArbitrationError
;
		btfsc	INDF2,	TXREQ,	0		; skip next if transmitted
		goto	TransmitRequest_7_Wait					
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_7_Wait1:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_7_NoDataError
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_7_Got1
;		
		goto	TransmitRequest_7_Wait1
;
TransmitRequest_7_Got1:
		lfsr	2,	RXB0D7				; point to the receive buffer
		call	DisplayRegisterBank		; display received packet
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_7_Wait2:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_7_NoMoreData
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_7_Got1
;		
		goto	TransmitRequest_7_Wait2
;
TransmitRequest_7_NoMoreData:		
		clrf	WREG
		goto	TransmitRequest_Exit
;		
TransmitRequest_7_NoDataError:
		decfsz	RETRY,	F,	0
		goto	TransmitRequest_7_Continue1
;
		bsf		EFLAG,	NDATA,	0		; No Data Error
		goto	TransmitRequest_Error		
;
TransmitRequest_7_ArbitrationError:
		bsf		EFLAG,	BBUSY,	0		; Bus Busy Error
		goto	TransmitRequest_Error	
;		
TransmitRequest_Chk4_8:
		movlw	8
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=8
		goto	TransmitRequest_Chk4_9		
;
TransmitRequest_8:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_8_Continue	; branch if protocol already set
;		
		call	SetProtocol_8
;
TransmitRequest_8_Continue:		
		movlw	RetryCount
		movwf	RETRY,	0
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_8_Continue1
;			
		movlw	UPPER P8
		movwf	TBLPTRU
		movlw	HIGH P8
		movwf	TBLPTRH
		movlw	LOW P8
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_8_Continue1:
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	TransmitRequest_8_Continue2
;
TransmitRequest_8_UseCAFF		
		movff	PCI,	TXBYTE0	
;
TransmitRequest_8_Continue2:
		lfsr	2,	TXB0D7		
		call	CANTransmit
;
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_50MS			; 50mS 
		movwf	TMR3H,	0
		movlw	LOW T3_50MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow		
;
TransmitRequest_8_Wait:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_8_ArbitrationError
;
		btfsc	INDF2,	TXREQ,	0		; skip next if transmitted
		goto	TransmitRequest_8_Wait					
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_8_Wait1:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_8_NoDataError
;
		tstfsz	RXSTAT,	0				; skip next if no reception
		goto	TransmitRequest_8_Got1
;		
		goto	TransmitRequest_8_Wait1
;
TransmitRequest_8_Got1:
		lfsr	2,	RXB0D7				; point to the receive buffer
		call	DisplayRegisterBank		; display received packet
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_8_Wait2:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_8_NoMoreData
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_8_Got1
;		
		goto	TransmitRequest_8_Wait2
;
TransmitRequest_8_NoMoreData:		
		clrf	WREG
		goto	TransmitRequest_Exit
;		
TransmitRequest_8_NoDataError:
		decfsz	RETRY,	F,	0
		goto	TransmitRequest_8_Continue1
;		
		bsf		EFLAG,	NDATA,	0		; No Data Error
		goto	TransmitRequest_Error		
;
TransmitRequest_8_ArbitrationError:
		bsf		EFLAG,	BBUSY,	0		; Bus Busy Error
		goto	TransmitRequest_Error
;		
TransmitRequest_Chk4_9:
		movlw	9
		cpfseq	PROTOCOL,	0				; skip next if PROTOCOL=9
		goto	TransmitRequest_Chk4_10		
;
TransmitRequest_9:
		movf	LASTPROTOCOL,	W,	0
		subwf	PROTOCOL,	W,	0
		bz		TransmitRequest_9_Continue	; branch if protocol already set
;		
		call	SetProtocol_9
;
TransmitRequest_9_Continue:		
		movlw	RetryCount
		movwf	RETRY,	0
		btfss	FLAG1,	DISPLAYPROTOCOL,	0	; skip next if we wnat protocol 
		goto	TransmitRequest_9_Continue1
;			
		movlw	UPPER P9
		movwf	TBLPTRU
		movlw	HIGH P9
		movwf	TBLPTRH
		movlw	LOW P9
		movwf	TBLPTRL
		call	DisplayMessage
;
		movff	PCI,	TXBYTE0
		call	DisplayCommand		
;
TransmitRequest_9_Continue1:
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	TransmitRequest_9_Continue2
;
TransmitRequest_9_UseCAFF		
		movff	PCI,	TXBYTE0	
;
TransmitRequest_9_Continue2:	
		lfsr	2,	TXB0D7		
		call	CANTransmit
;
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_50MS			; 50mS 
		movwf	TMR3H,	0
		movlw	LOW T3_50MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow		
;
TransmitRequest_9_Wait:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_9_ArbitrationError
;
		btfsc	INDF2,	TXREQ,	0		; skip next if transmitted
		goto	TransmitRequest_9_Wait					
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_9_Wait1:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_9_NoDataError
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_9_Got1
;		
		goto	TransmitRequest_9_Wait1
;
TransmitRequest_9_Got1:
		lfsr	2,	RXB0D7				; point to the receive buffer
		call	DisplayRegisterBank		; display received packet
;
		clrf	RXSTAT,	0				; initialize no reception
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		movlw	HIGH T3_5MS				; 5mS 
		movwf	TMR3H,	0
		movlw	LOW T3_5MS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
TransmitRequest_9_Wait2:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no timeout
		goto	TransmitRequest_9_NoMoreData
;
		tstfsz	RXSTAT		,	0		; skip next if no reception
		goto	TransmitRequest_9_Got1
;		
		goto	TransmitRequest_9_Wait2
;
TransmitRequest_9_NoMoreData:		
		clrf	WREG
		goto	TransmitRequest_Exit
;		
TransmitRequest_9_NoDataError:
		decfsz	RETRY,	F,	0
		goto	TransmitRequest_9_Continue1
;
		bsf		EFLAG,	NDATA,	0		; No Data Error
		goto	TransmitRequest_Error		
;
TransmitRequest_9_ArbitrationError:
		bsf		EFLAG,	BBUSY,	0		; Bus Busy Error
		goto	TransmitRequest_Error	
;		
TransmitRequest_Chk4_10:
		movlw	D'10'
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=10
		goto	TransmitRequest_Chk4_11		
;
TransmitRequest_10:
		goto	TransmitRequest_Error		
;		
TransmitRequest_Chk4_11:
		movlw	D'11'
		cpfseq	PROTOCOL,	0				; skip next if PROTOCOL=11
		goto	TransmitRequest_Chk4_12		
;
TransmitRequest_11:
		goto	TransmitRequest_Error
;		
TransmitRequest_Chk4_12:
		movlw	D'12'
		cpfseq	PROTOCOL,	0				; skip next if PROTOCOL=12
		goto	TransmitRequest_Error		
;
TransmitRequest_12:
		goto	TransmitRequest_Error		
;
TransmitRequest_Error:
		call	SendErrors
;		
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		setf	WREG,	0				; error	
;							
TransmitRequest_Exit:
		return	
;
;***************************************;***************************************
;
;	Display Command
;
;***************************************;***************************************
;	
DisplayCommand:
		movlw	0x06
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=6
		goto	DisplayCommand1
;		
		goto	DisplayCommand_12bits
;
DisplayCommand1:
		movlw	0x08
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=8
		goto	DisplayCommand_24bits
;		
		goto	DisplayCommand_12bits		
;
DisplayCommand_24bits:
		movlw	a'('
		movwf	CHAR
		call	UserOutput
;	
		swapf	HEADERU,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	HEADERU,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		swapf	HEADERH,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	HEADERH,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		swapf	HEADERL,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	HEADERL,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		btfss	FLAG,	SF,	0			; skip next if we want spaces
		goto	DisplayCommand_24bits_Continue
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput			
;
DisplayCommand_24bits_Continue:
		goto	DisplayCommand_12bits_Continue		
;
DisplayCommand_12bits:
		movlw	a'('
		movwf	CHAR
		call	UserOutput
;		
		movf	HEADERH,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;				
		swapf	HEADERL,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	HEADERL,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		btfss	FLAG,	SF,	0			; skip next if we want spaces
		goto	DisplayCommand_12bits_Continue
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput					
;
DisplayCommand_12bits_Continue:
		lfsr	2,	TXBYTE0
		movff	INDF2,	TEMP1
		incf	TEMP1,	F,	0
;		
DisplayCommand_Loop:		
		tstfsz	TEMP1,	0				; skip next if no more bytes to display
		goto	DisplayCommand_1	
;		
		goto	DisplayCommand_Exit		
;
DisplayCommand_1:
		swapf	INDF2,	W
		andlw	0x0F		
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		movf	POSTINC2,	W
		andlw	0x0F		
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		btfss	FLAG,	SF,	0			; skip next if we want spaces
		goto	DisplayCommand_Continue1
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput
;
DisplayCommand_Continue1:
		decf	TEMP1,	F,	0
		goto	DisplayCommand_Loop
;
DisplayCommand_Exit:
		movlw	a')'
		movwf	CHAR
		call	UserOutput
;
		call	SendCR
;				
		return		
;
;***************************************;***************************************
;
;	Display register bank
;
;***************************************;***************************************
;
DisplayRegisterBank:
		bcf		CFLAG,	SFRAME,	0			; clear any a SF
		bcf		CFLAG,	FFRAME,	0			; clear any a FF
		bcf		CFLAG,	CFRAME,	0			; clear any a CF
		bcf		CFLAG,	FCONTROL,	0		; clear any a FC
;								
		movff	POSTDEC2,	RXBYTE7
		movff	POSTDEC2,	RXBYTE6
		movff	POSTDEC2,	RXBYTE5
		movff	POSTDEC2,	RXBYTE4
		movff	POSTDEC2,	RXBYTE3
		movff	POSTDEC2,	RXBYTE2
		movff	POSTDEC2,	RXBYTE1
		movff	POSTDEC2,	RXBYTE0
		movff	POSTDEC2,	RXBDLC
		movff	POSTDEC2,	RXEIDL
		movff	POSTDEC2,	RXEIDH
		movff	POSTDEC2,	RXSIDL
		movff	POSTDEC2,	RXSIDH
;
		movff	RXBYTE0,	TEMP1
;		
DisplayRegisterBank_FormatCheck:
		movlw	0xF0
		andwf	TEMP1,	F,	0
		tstfsz	TEMP1,	0					; skip next if Single Frame format 
		goto	DisplayRegisterBank_Data_Chk4FF
;
DisplayRegisterBank_Data_SF:
		bsf		CFLAG,	SFRAME,	0			; flag a SF
		goto	DisplayRegisterBank_IDCheck	; just continue normally
;
DisplayRegisterBank_Data_Chk4FF:
		movlw	0x10
		cpfseq	TEMP1,	0					; skip if First Frame Frame Control
		goto	DisplayRegisterBank_Data_Chk4CF
;
DisplayRegisterBank_Data_FF:				; special display
		bsf		CFLAG,	FFRAME,	0			; flag a FF
		swapf	RXBYTE0,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		movf	RXBYTE0,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		call	SendCR
;
		movf	RXBYTE0,	W,	0
		andlw	0x0F
		iorlw	0x30						; make it ASC
		movwf	CHAR,	0
		call	UserOutput
;
		movlw	A':'
		movwf	CHAR,	0
		call	UserOutput		
;
		movlw	A' '
		movwf	CHAR,	0
		call	UserOutput		
;
		movlw	6
		movwf	TEMP1
		lfsr	2,	RXBYTE2
		goto	DisplayRegisterBank_IDCheck		
;
DisplayRegisterBank_Data_Chk4CF
		movlw	0x20
		cpfseq	TEMP1,	0					; skip if First Frame Frame Control
		goto	DisplayRegisterBank_Exit	; else just leave
;		
DisplayRegisterBank_Data_CF:				; special display
		bsf		CFLAG,	CFRAME,	0			; flag a CF
		movf	RXBYTE0,	W,	0
		andlw	0x0F
		iorlw	0x30						; make it ASC
		movwf	CHAR,	0
		call	UserOutput
;
		movlw	A':'
		movwf	CHAR,	0
		call	UserOutput		
;
		movlw	A' '
		movwf	CHAR,	0
		call	UserOutput		
;
		movlw	7
		movwf	TEMP1
		lfsr	2,	RXBYTE1
		goto	DisplayRegisterBank_IDCheck		
;
DisplayRegisterBank_IDCheck:		
		btfss	FLAG,	HF,	0			; skip next if we want headers
		goto	DisplayRegisterBank_Data
;
DisplayRegisterBank_StandardID:
		btfsc	RXSIDL,	EXIDE,	0		; skip next if standard identifier
		goto	DisplayRegisterBank_ExtendedID
;
		movff	RXSIDL,	TEMPL
		movff	RXSIDH,	TEMPH				
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
;
		
;
		movf	TEMPH,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		swapf	TEMPL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	TEMPL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput				
;
		goto	DisplayRegisterBank_SP	
;
DisplayRegisterBank_ExtendedID:
		movlw	0x03
		andwf	TEMP,	F,	0			; save bits 29:28 in TEMP
		bcf		STATUS,	C,	0
;
		movff	RXSIDL,	TEMPL
		movff	RXSIDH,	TEMPH
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		bcf		STATUS,	C,	0
		rrcf	TEMPH,	F,	0
		rrcf	TEMPL,	F,	0
		movlw	0xFC	
		andwf	TEMPL,	F,	0	
		movf	TEMP,	W,	0
		iorwf	TEMPL,	F,	0				
;
		swapf	TEMPH,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	TEMPH,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput	
;
		swapf	TEMPL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	TEMPL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		swapf	RXEIDH,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	RXEIDH,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput	
;
		swapf	RXEIDL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	RXEIDL,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput			
;
DisplayRegisterBank_SP:
		btfss	FLAG,	SF,	0			; skip next if we want spaces
		goto	DisplayRegisterBank_Data
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput				
;
DisplayRegisterBank_Data:
		btfsc	CFLAG,	FFRAME,	0		; skip next if not a FF
		goto	DisplayRegisterBank_Loop; else TEMP1 and pointer are preset
;
		btfsc	CFLAG,	CFRAME,	0		; skip next if not a CF
		goto	DisplayRegisterBank_Loop; else TEMP1 and pointer are preset
;				
		lfsr	2,	RXBYTE0
		movff	INDF2,	TEMP1
;
DisplayRegisterBank_Continue:		
		incf	TEMP1,	F,	0
		btfss	FLAG,	CAFF,	0		; skip next if auto formatting is ON
		goto	DisplayRegisterBank_Loop
;
DisplayRegisterBank_DataAF:	
		decf	TEMP1,	F,	0
		lfsr	2,	RXBYTE1			
;
DisplayRegisterBank_Loop:		
		movlw	0x00
		cpfsgt	TEMP1,	0				; skip next if PCI<>0
		goto	DisplayRegisterBank_Done
;
		swapf	INDF2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	POSTINC2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;		
		decf	TEMP1,	F,	0
		btfss	FLAG,	SF,	0			; skip next if we want spaces
		goto	DisplayRegisterBank_Loop
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput		
		goto	DisplayRegisterBank_Loop
;														
DisplayRegisterBank_Done:
		call	SendCR
;
		btfsc	CFLAG,	FFRAME,	0		; skip next if not FF
		call	SendFlowControl
;
DisplayRegisterBank_Exit:		
		return	
;
;***************************************;***************************************
;
;	Send a Flow Control Packet
;
;***************************************;***************************************
;		
SendFlowControl:
		btfsc	RXSIDL,EXIDE,	0
		goto	SendFlowControl_Ext
;
SendFlowControl_Std:		
		movff	RXSIDH,	TXSIDH
		bcf		TXSIDH,	0,	0
		movff	RXSIDL,	TXSIDL
		movff	RXEIDH,	TXEIDH
		movff	RXEIDL,	TXEIDL
;
		goto	SendFlowControl_Continue
;
SendFlowControl_Ext:
		movff	RXSIDH,	TXSIDH
		movff	RXSIDL,	TXSIDL
		movff	RXEIDH,	TXEIDL
		movff	RXEIDL,	TXEIDH				
		goto	SendFlowControl_Continue		
;		
SendFlowControl_Continue:		
		movlw	0x30					; flow control frame
		movwf	TXBYTE0,	0
		movlw	0x08					; 8 byte / response
		movwf	TXBYTE1,	0
		movlw	0x01					; 1mS between response
		movwf	TXBYTE2,	0
		clrf	TXBYTE3,	0
		clrf	TXBYTE4,	0
		clrf	TXBYTE5,	0
		clrf	TXBYTE6,	0												
		clrf	TXBYTE7,	0
;		
		lfsr	2,	TXB0D7
		call	CANTransmit
;				
		return
;
;***************************************;***************************************
;
;	Display response
;
;***************************************;***************************************
;
DisplayResponse:
		movff	RRESPONSES,	RXCOUNT
		clrf	RESPONSECOUNT
;
DisplayResponse_Loop:
		lfsr	2,	RX1COUNT
		movlw	D'13'					; length of response buffer
		mulwf	RESPONSECOUNT,	0
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0
;
		movff	POSTINC2,	TEMP1
		tstfsz	RXCOUNT,	0			; skip next if nothing to Display
		goto	DisplayResponse_Chk4HF
;
		goto	DisplayResponse_Exit	
;
DisplayResponse_Chk4HF:
		btfsc	FLAG,	HF,	0			; skip next if no headers
		goto	DisplayResponse_HeaderU
;
		movf	POSTINC2,	W,	0		; dummy to inc pointer
		movf	POSTINC2,	W,	0
		movf	POSTINC2,	W,	0		
		goto	DisplayResponse_Data
;
DisplayResponse_HeaderU:
		swapf	INDF2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;
		movf	POSTINC2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
DisplayResponse_HeaderH:
		swapf	INDF2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		movf	POSTINC2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC	
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
DisplayResponse_HeaderL:
		swapf	INDF2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;
		movf	POSTINC2,	W,	0		
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC	
;		
		movff	VALUE,	CHAR
		call	UserOutput				
;
DisplayResponse_SP:
		btfss	FLAG,	SF,	0				; skip next if we want spaces
		goto	DisplayResponse_Data
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput				
;
DisplayResponse_Data:
		decf	TEMP1,	F,	0			; reduce count by header size		
		decf	TEMP1,	F,	0						
		decf	TEMP1,	F,	0
		btfss	FLAG,	HF,	0			; skip next if we want Checksum (Headers)
		decf	TEMP1,	F,	0			; else don't display the checksum		
;
DisplayResponse_DataLoop:
		tstfsz	TEMP1,	0					; skip next if done
		goto	DisplayResponse_Continue
;		
		goto	DisplayResponse_CR
;
DisplayResponse_Continue:				
		swapf	INDF2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	POSTINC2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;		
		decf	TEMP1,	F,	0
		btfss	FLAG,	SF,	0				; skip next if we want spaces
		goto	DisplayResponse_DataLoop
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput		
		goto	DisplayResponse_DataLoop
;														
DisplayResponse_CR:
		call	SendCR
;
		decf	RXCOUNT,	F,	0
		incf	RESPONSECOUNT,	F,	0
		goto	DisplayResponse_Loop		
;
DisplayResponse_Exit:		
		return	
		;
;***************************************;***************************************
;
;	Display IFR
;
;***************************************;***************************************
;
DisplayIFR:
		lfsr	2,	RXCOUNT
		movff	POSTINC2,	TEMP1
;
DisplayIFR_Loop:
		tstfsz	TEMP1,	0					; skip next if done
		goto	DisplayIFR_Continue
;		
		goto	DisplayIFR_Exit
;
DisplayIFR_Continue:				
		swapf	INDF2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput
;		
		movf	POSTINC2,	W,	0
		andlw	0x0F
		movwf	VALUE,	0
		call	GetASC
;		
		movff	VALUE,	CHAR
		call	UserOutput		
;		
		decf	TEMP1,	F,	0
		btfss	FLAG,	SF,	0				; skip next if we want spaces
		goto	DisplayIFR_Loop
;
		movlw	a' '
		movwf	CHAR
		call	UserOutput		
		goto	DisplayIFR_Loop
;														
DisplayIFR_Exit:
		call	SendCR
;		
		return					
;
;***************************************;***************************************
;
;	Get binary value of ASCII number
;
;	VALUE (binary)	=	VALUE (ascii)
;
;	WREG	=	0=OK, else Error
;***************************************;***************************************
;
GetValue:	
		movlw	0x2F					
		cpfsgt	VALUE,	0				; skip next if VALUE>ASCII(0)
		goto	GetValue_Error
;		
		movlw	0x39					
		cpfsgt	VALUE,	0				; skip next if VALUE>ASCII(9)
		goto	GetValue_0_9
;
		movlw	0x40					
		cpfsgt	VALUE,	0				; skip next if VALUE>ASCII(@)
		goto	GetValue_Error
;		
		movlw	0x46					
		cpfsgt	VALUE,	0				; skip next if VALUE>ASCII(F)
		goto	GetValue_A_F
;
GetValue_Error:
		setf	WREG
		goto	GetValue_Exit							
;
GetValue_0_9:
		movlw	0x30	
		subwf	VALUE,	F,	0			; VALUE=VALUE-0x30
		goto	GetValue_OK
;
GetValue_A_F:
		movlw	0x37	
		subwf	VALUE,	F,	0			; VALUE=VALUE-0x37
;
GetValue_OK:
		clrf	WREG
;
GetValue_Exit:				
		return
;
;***************************************;***************************************
;
;	Get ASCII value of binary number
;
;	VALUE	=	binary
;	VALUE	=	ASCII
;
;***************************************;***************************************
;
GetASC:	
		movlw	0x09					
		cpfsgt	VALUE,	0				; skip next if VALUE>9
		goto	GetASC_0_9				; else must be 0-9
;
GetASC_A_F:
		movlw	0x37	
		addwf	VALUE,	F,	0			; VALUE=VALUE+0x37
		goto	GetASC_Exit	
;		
GetASC_0_9:
		movlw	0x30	
		addwf	VALUE,	F,	0			; VALUE=VALUE+0x30
;
GetASC_Exit:				
		return
;
;***************************************;***************************************
;
;	PWM Bit Bang Transmission
;
;	HEADERU/H/L contain the header
;	PCI = number of characters to send (minus 3 headers and 1 checksum)
;	TXBYTE0-7 = characters
;	CHECKSUM = CRC-8-SAE 1850 
;
;	uses 	
;		TEMP
;		TEMP1
;
;	returns
;		WREG 0=success, 1=arbitration failure
;
;***************************************;***************************************
;		
PWMTransmit:
		lfsr	2,	TXBBHU
		movff	HEADERU,	POSTINC2
		movff	HEADERH,	POSTINC2		
		movff	HEADERL,	POSTINC2		
;
		movff	PCI,	TEMP
		movlw	4
		addwf	TEMP,	W,	0
		movwf	TXCOUNT
		lfsr	1,	TXBYTE1
;
PWMTransmit_Loop1:						; build transmit buffer
		movff	POSTINC1,	POSTINC2
		decfsz	TEMP,	F,	0
		goto	PWMTransmit_Loop1			
;
		movlw	0xFF
		movwf	CHECKSUM,	0			; save the seed	
		lfsr	2,	TXBBHU
		decf	TXCOUNT,	W,	0		; length to exclude CRC byte
		movwf	TEMP,	0
;
PWMTransmit_Loop2:						; calculate CRC
		movf	POSTINC2,	W,	0
		call	CRC
		decfsz	TEMP,	F,	0
		goto	PWMTransmit_Loop2
;
		movlw	0xFF
		xorwf	CHECKSUM,	F			; final XOR
		movff	CHECKSUM,	INDF2		; place final CRC 
;						
		bcf		PIR1,	TMR2IF,	0
;		
PWMTransmit_Chk4Activity:
		btfss	PIR1,	TMR2IF,	0
		goto	PWMTransmit_Chk4Activity
;
		bcf		PIR1,	TMR2IF,	0		; clear flag now in a timing period	
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
		movlw	6
		movwf	TEMP
;
PWMTransmit_Chk4Activity_Loop:		
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	PWMTransmit_Wait
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	PWMTransmit_Wait
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	PWMTransmit_Chk4Activity_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	PWMTransmit_Chk4Activity_Loop	
;		
PWMTransmit_SOF:
		bcf		INTCON,	GIEH,	0
		bcf		INTCON,	GIEL,	0		
;		
PWMTransmit_SOF_Loop:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	PWMTransmit_SOF_Loop
;		
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	PWMTransmit_Wait
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	PWMTransmit_Wait
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
		movlw	4
		movwf	TEMP,	0
;
PWMTransmit_SOF_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	PWMTransmit_SOF_Loop1
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		decfsz	TEMP,	F,	0
		goto	PWMTransmit_SOF_Loop1	
;		
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
;
PWMTransmit_SOF_Loop2:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	PWMTransmit_SOF_Loop2
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;
PWMTransmit_SendDATA:
		movff	TXCOUNT,	TEMP1
		lfsr	2,	TXBBHU
;
PWMTransmit_SendDATA_ByteLoop:
		movff	POSTINC2,	CHAR
		call	SendBytePWM
;
		tstfsz	WREG,	0				; skip next if no arbitratio
		goto	PWMTransmit_Wait		; else leave with error
;
		decfsz	TEMP1,	F,	0
		goto	PWMTransmit_SendDATA_ByteLoop
;
PWMTransmit_Loop3:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 1st period
		goto	PWMTransmit_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
		clrf	WREG					; OK
;
		call	Look4PWMIFR	
;			
		tstfsz	RXCOUNT,	0			; skip next if no characters
		goto	PWMTransmit_GotResponse
;
		goto	PWMTransmit_Wait
;
PWMTransmit_GotResponse	
		btfsc	RFLAG,	DISPLAYRESPONSE,	0			
		call	DisplayIFR
;
		clrf	WREG,	0
		goto	PWMTransmit_Exit
;
PWMTransmit_Wait:
		setf	WREG					; error		
;
PWMTransmit_Exit:
		bsf		INTCON,	GIEH,	0
		bsf		INTCON,	GIEL,	0				
		return
;
;***************************************;***************************************
;
;	CRC-8-SAE
;
;	WREG = DATA
;	TABLEOFFSET = DATA XOR CHECKSUM
;	CHECKSUM = TableEntry 
;
;		
;	CHECKSUM = 0x0A for Protocol1 0x61, 0x6A, 0xF1, 0x01, 0x00 	
;	CHECKSUM = 0x17 for Protocol1 0x68, 0x6A, 0xF1, 0x01, 0x00 	
;
;***************************************;***************************************
;
CRC:
		xorwf	CHECKSUM,	F,	0
		movff	CHECKSUM,	TBLPTRL
		movlw	UPPER CRCTABLE
		movwf	TBLPTRU
		movlw	HIGH CRCTABLE
		movwf	TBLPTRH			
		movlw	LOW CRCTABLE
		addwf	TBLPTRL,	F,	0
		clrf	WREG		
		addwfc	TBLPTRH,	F,	0
		TBLRD	*
		movff	TABLAT,		CHECKSUM
		return	
;
;***************************************;***************************************
;
;	VPM Bit Bang Transmission
;
;	HEADERU/H/L contain the header
;	PCI = number of characters to send (minus 3 headers and 1 checksum)
;	TXBYTE0-7 = characters
;	CHECKSUM = CRC-8-SAE 1850 
;
;	uses 	
;		TEMP
;		TEMP1
;
;	returns
;		WREG 0=success, 1=arbitration failure
;
;***************************************;***************************************
;		
VPWTransmit:
		bcf		INTCON,	GIEL,	0
		lfsr	2,	TXBBHU
		movff	HEADERU,	POSTINC2
		movff	HEADERH,	POSTINC2		
		movff	HEADERL,	POSTINC2		
;
		movff	PCI,	TEMP
		movlw	4
		addwf	TEMP,	W,	0
		movwf	TXCOUNT
		lfsr	1,	TXBYTE1
;
VPWTransmit_Loop1:						; build transmit buffer
		movff	POSTINC1,	POSTINC2
		decfsz	TEMP,	F,	0
		goto	VPWTransmit_Loop1			
;
		movlw	0xFF
		movwf	CHECKSUM,	0			; save the seed	
		lfsr	2,	TXBBHU
		decf	TXCOUNT,	W,	0		; length to exclude CRC byte
		movwf	TEMP,	0
;
VPWTransmit_Loop2:						; calculate CRC
		movf	POSTINC2,	W,	0
		call	CRC
		decfsz	TEMP,	F,	0
		goto	VPWTransmit_Loop2
;
		movlw	0xFF
		xorwf	CHECKSUM,	F			; final XOR
		movff	CHECKSUM,	INDF2		; place final CRC 
;						
		bcf		PIR1,	TMR2IF,	0
;		
VPWTransmit_Chk4Activity:
		btfss	PIR1,	TMR2IF,	0
		goto	VPWTransmit_Chk4Activity
;
		bcf		PIR1,	TMR2IF,	0		; clear flag now in a timing period	
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
		movlw	9						; 300uS
		movwf	TEMP
;
VPWTransmit_Chk4Activity_Loop:		
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	VPWTransmit_Wait
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	VPWTransmit_Wait
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	VPWTransmit_Chk4Activity_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	VPWTransmit_Chk4Activity_Loop	
;		
VPWTransmit_SOF:
VPWTransmit_SOF_Loop:
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	VPWTransmit_Wait
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	VPWTransmit_Wait
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	VPWTransmit_SOF_Loop
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
		movlw	6						; 200uS
		movwf	TEMP,	0
;
VPWTransmit_SOF_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	VPWTransmit_SOF_Loop1
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		decfsz	TEMP,	F,	0
		goto	VPWTransmit_SOF_Loop1	
;
		bsf		FLAG1,	LASTVPWSTATE	; setup bit state			
;
VPWTransmit_SendDATA:
		movff	TXCOUNT,	TEMP1
		lfsr	2,	TXBBHU
;
VPWTransmit_SendDATA_ByteLoop:
		movff	POSTINC2,	CHAR
		call	SendByteVPW
;
		tstfsz	WREG,	0				; skip next if found passive
		goto	VPWTransmit_Wait		; else leave with error
;
		decfsz	TEMP1,	F,	0
		goto	VPWTransmit_SendDATA_ByteLoop
;
VPWTransmit_Loop3:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	VPWTransmit_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
		clrf	WREG					; OK
		goto	VPWTransmit_Exit
;
VPWTransmit_Wait:
		setf	WREG					; error		
;
VPWTransmit_Exit:
		bsf		INTCON,	GIEL,	0
		return	
;
;***************************************;***************************************
;
;	ISO BitBang Transmission
;
;	HEADERU/H/L contain the header
;	PCI = number of characters to send (minus 3 headers and 1 checksum)
;	TXBYTE0-7 = characters
;	CHECKSUM = LSByte of the total of all bytes (up to CHECKSUM)
;
;	uses 	
;		TEMP
;		TEMP1
;
;	returns
;		WREG 0=success, 1=arbitration failure
;
;***************************************;***************************************
;		
ISOTransmit:
		lfsr	2,	TXBBHU
		movff	HEADERU,	POSTINC2
		movff	HEADERH,	POSTINC2		
		movff	HEADERL,	POSTINC2		
;
		movff	PCI,	TEMP
		movlw	4
		addwf	TEMP,	W,	0
		movwf	TXCOUNT,	0
		lfsr	1,	TXBYTE1
;
ISOTransmit_Loop1:						; build transmit buffer
		movff	POSTINC1,	POSTINC2
		decfsz	TEMP,	F,	0
		goto	ISOTransmit_Loop1			
;
		movlw	0x00
		movwf	CHECKSUM,	0			; initialize checksum
		lfsr	2,	TXBBHU
		decf	TXCOUNT,	W,	0		; length to exclude CRC byte
		movwf	TEMP,	0
;
ISOTransmit_Loop2:						; calculate CRC
		movf	POSTINC2,	W,	0
		addwf	CHECKSUM,	F,	0
		decfsz	TEMP,	F,	0
		goto	ISOTransmit_Loop2
;
		movff	CHECKSUM,	INDF2		; place final CRC 
;
;	TX buffer now loaded go send it
;		
		bcf		PIR1,	TMR2IF,	0
;		
ISOTransmit_Chk4Activity:
		btfss	PIR1,	TMR2IF,	0
		goto	ISOTransmit_Chk4Activity
;
		bcf		PIR1,	TMR2IF,	0		; clear flag now in a timing period	
		movlw	9						; 300uS
		movwf	TEMP
;
ISOTransmit_Chk4Activity_Loop:		
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	ISOTransmit_Wait
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	ISOTransmit_Chk4Activity_Loop
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		decfsz	TEMP,	F,	0
		goto	ISOTransmit_Chk4Activity_Loop	
;
ISOTransmit_SendDATA:
		movff	TXCOUNT,	TEMP1
		lfsr	2,	TXBBHU
;
ISOTransmit_SendDATA_ByteLoop:
		movff	POSTINC2,	CHAR
		call	SendByteISO
;
		btfsc	RFLAG,	ARBITRATION,	0	; skip next success
		goto	ISOTransmit_Wait		; else leave with error
;
		decfsz	TEMP1,	F,	0
		goto	ISOTransmit_SendDATA_ByteLoop
;
ISOTransmit_Loop3:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	ISOTransmit_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		clrf	WREG					; OK
		goto	ISOTransmit_Exit
;
ISOTransmit_Wait:
		setf	WREG,	0		
;
ISOTransmit_Exit:
		return				
;
;***************************************;***************************************
;
;	Send 1 byte of DATA (PWM)
;
;***************************************;***************************************
;
SendBytePWM:
		movlw	8
		movwf	TEMP,	0
;
SendBytePWM_BitLoop:
		rlcf	CHAR,	F,	0
		btfss	STATUS,	C,	0			; skip next if bit is '1'
		goto	SendBytePWM_Send0
;
SendBytePWM_Send1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 1st period
		goto	SendBytePWM_Send1
;
		movf	PORTC,	W,	0	
;		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
;		goto	SendBytePWM_Send1_Error
;		
;		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
;		goto	SendBytePWM_Send1_Error
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
;
SendBytePWM_Send1_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 2nd period
		goto	SendBytePWM_Send1_Loop1
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag				
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
;
SendBytePWM_Send1_Loop2:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 3rd period
		goto	SendBytePWM_Send1_Loop2
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag	
		goto	SendBytePWM_Continue
;
SendBytePWM_Send1_Error:
		setf	WREG,	0
		goto	SendBytePWM_Exit			; else leave with error		
;
SendBytePWM_Send0:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 1st period
		goto	SendBytePWM_Send0
;		
		movf	PORTC,	W,	0	
;		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
;		goto	SendBytePWM_Send0_Error
;		
;		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
;		goto	SendBytePWM_Send0_Error
;		
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
;
SendBytePWM_Send0_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 2nd period
		goto	SendBytePWM_Send0_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;
SendBytePWM_Send0_Loop2:
		btfss	PIR1,	TMR2IF,	0		; waiting to start 3rd period
		goto	SendBytePWM_Send0_Loop2
;		
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		goto	SendBytePWM_Continue
;
SendBytePWM_Send0_Error:
		setf	WREG,	0
		goto	SendBytePWM_Exit			; else leave with error			
;
SendBytePWM_Continue:	
		decfsz	TEMP,	F,	0
		goto	SendBytePWM_BitLoop
;
		clrf	WREG,	0
;		
SendBytePWM_Exit:
		return
;
;***************************************;***************************************
;
;	Send 1 byte of DATA (VPW)
;
;***************************************;***************************************
;
SendByteVPW:
		movlw	8
		movwf	TEMP,	0
;
SendByteVPW_BitLoop:
		rlcf	CHAR,	F,	0
		btfss	STATUS,	C,	0			; skip next if bit is '1'
		goto	SendByteVPW_Send0
;
SendByteVPW_Send1:
		btfss	FLAG1,	LASTVPWSTATE,	0	; skip next if was active
		goto	SendByteVPW_Send1_Active
;
SendByteVPW_Send1_Passive:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Passive
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state	
;		
SendByteVPW_Send1_Passive_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Passive_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;		
SendByteVPW_Send1_Passive_Loop2:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Passive_Loop2
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;		
SendByteVPW_Send1_Passive_Loop3:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Passive_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag				
;			
		bcf		FLAG1,	LASTVPWSTATE,	0
		goto	SendByteVPW_Continue
;
SendByteVPW_Send1_Active:
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	SendByteVPW_Error
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	SendByteVPW_Error
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Active
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
;		
SendByteVPW_Send1_Active_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send1_Active_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag		
		bsf		FLAG1,	LASTVPWSTATE,	0
		goto	SendByteVPW_Continue
;
SendByteVPW_Send0:
		btfss	FLAG1,	LASTVPWSTATE,	0	; skip next if was active
		goto	SendByteVPW_Send0_Active
;
SendByteVPW_Send0_Passive:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Passive
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bcf		LATA,	B_PLUS,	0		; passive state
		bcf		LATC,	B_MINUS,	0	; passive state	
;		
SendByteVPW_Send0_Passive_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Passive_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag			
		bcf		FLAG1,	LASTVPWSTATE,	0
		goto	SendByteVPW_Continue
;
SendByteVPW_Send0_Active:
		movf	PORTC,	W,	0	
		btfsc	WREG,	B_PLUS_SEN,	0	; skip next if passive
		goto	SendByteVPW_Error
;		
		btfss	WREG,	B_MINUS_SEN,	0	; skip next if passive
		goto	SendByteVPW_Error
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Active
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATA,	B_PLUS,	0		; active state
		bsf		LATC,	B_MINUS,	0	; active state
;		
SendByteVPW_Send0_Active_Loop1:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Active_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;		
SendByteVPW_Send0_Active_Loop2:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Active_Loop2
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;		
SendByteVPW_Send0_Active_Loop3:
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteVPW_Send0_Active_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag						
		bsf		FLAG1,	LASTVPWSTATE,	0
		goto	SendByteVPW_Continue
;
SendByteVPW_Error:
		setf	WREG,	0
 		goto	SendByteVPW_Exit		; else leave with error	
;
SendByteVPW_Continue:
		decfsz	TEMP,	F,	0
		goto	SendByteVPW_BitLoop
;
		clrf	WREG,	0
;		
SendByteVPW_Exit:
		return
;
;***************************************;***************************************
;
;	Send 1 byte of DATA (ISO)
;
;	CHAR holds the data to send
;	RFLAG.ARBITRATION 1=found Active state while Passive
;	Timer 2 is set for 1/3 bit time (32uS for 10400 baud)
;
;***************************************;***************************************
;
SendByteISO:
		bcf		INTCON,	GIEL,	0
		bcf		INTCON,	GIEH,	0
		bcf		RFLAG,	ARBITRATION, 0
		movlw	8
		movwf	TEMP,	0
		bcf		PIR1,	TMR2IF,	0		
;		
SendByteISO_Startbit_Loop1:				; '0' active
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	SendByteISO_Error
;		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Startbit_Loop1	
;
SendByteISO_Startbit:
		call	SendByteISO_Send0	
;
SendByteISO_BitLoop:
		rrcf	CHAR,	F,	0			; LSBfirst
		btfss	STATUS,	C,	0			; skip next if bit is '1'
		goto	SendByteISO_Bit_0
;
SendByteISO_Bit_1:
		call	SendByteISO_Send1
		goto	SendByteISO_BitContinue	
;		
SendByteISO_Bit_0:		
		call	SendByteISO_Send0
;
SendByteISO_BitContinue					
		decfsz	TEMP,	F,	0
		goto	SendByteISO_BitLoop			
;
SendByteISO_Stopbit:
		call	SendByteISO_Send1	
		clrf	WREG,	0
 		goto	SendByteISO_Exit		; else leave with error
;
SendByteISO_Error:
		bsf		RFLAG,	ARBITRATION,	0
;		
SendByteISO_Exit:
		bsf		INTCON,	GIEL,	0
		bsf		INTCON,	GIEH,	0
		return			
;
;***************************************
;
SendByteISO_Send1:						; '1' passive
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send1
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bcf		LATB,	K,	0			; clear for passive
;		bcf		LATB,	L,	0			; clear for passive
;
SendByteISO_Send1_Loop2:			
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send1_Loop2
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;
SendByteISO_Send1_Loop3:
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	SendByteISO_Error
;				
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send1_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		return
;
;***************************************
;
SendByteISO_Send0:						; '0' active
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send0
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		bsf		LATB,	K,	0			; set for Active
;		bsf		LATB,	L,	0			; set for Active
;
SendByteISO_Send0_Loop2:			
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send0_Loop2
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
;
SendByteISO_Send0_Loop3:		
		btfss	PIR1,	TMR2IF,	0		; waiting to start period
		goto	SendByteISO_Send0_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear wait flag
		return
;
;***************************************;***************************************
;
;	Wake Up ECM
;
;	Timer 3 used for wakeup
;	T3_50MS time is used for slow init 
;	T3_25MS time is used for fast init
;
;
;	interrupts disabled
;
;***************************************;***************************************
;
Wakeup:
		movlw	UPPER BusInit
		movwf	TBLPTRU
		movlw	HIGH BusInit
		movwf	TBLPTRH
		movlw	LOW BusInit
		movwf	TBLPTRL
		call	DisplayMessageNOCR
;
		movlw	RetryCount
		movwf	RETRY,	0		
;	
Wakeup1:	
		movlw	HIGH T3_50MS			; 50mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD
		movlw	6						; 300mS
		movwf	TEMP				
;
Wakeup_Chk4Activity:
		call	T3Wait	
;			
		btfss	RFLAG,	ARBITRATION,	0	; skip next if no Arbitration
		goto	Wakeup_Continue
;				
		decfsz	RETRY,	F,	0			; decrement and skip if = 0
		goto	Wakeup1
;
		goto	Wakeup_BusBusyError		
;
Wakeup_Continue:	
		btfss	FLAG1,	INIT,	0		; skip next if we want fast init
		goto	Wakeup_Slow
;
Wakeup_Fast:
		bsf		LATB,	K,	0			; set for Active
		bsf		LATB,	L,	0			; set for Active
		movlw	HIGH T3_25MS			; 25mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_25MS
		movwf	TMR3L_RELOAD
		movlw	1						; 25mS
		movwf	TEMP						
		call	T3Wait
;
		bcf		LATB,	K,	0			; clear for Passive
		bcf		LATB,	L,	0			; clear for Passive		
		movlw	HIGH T3_25MS			; 25mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_25MS
		movwf	TMR3L_RELOAD
		movlw	1						; 25mS
		movwf	TEMP						
		call	T3Wait
;		
Wakeup_Fast_Command:
		lfsr	2,	TXBBHU
		movlw	0xC1
		movwf	TXBBHU,	0
		movlw	0x33
		movwf	TXBBHH,	0
		movlw	0xF1
		movwf	TXBBHL,	0		
		movlw	0x81
		movwf	TXBBD0,	0
		movlw	0x66
		movwf	TXBBD1
		movlw	5
		movwf	TEMP1,	0
;
Wakeup_Fast_Command_Loop:
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		tstfsz	WREG,	0				; skip next if found passive
		goto	Wakeup_BusBusyError		; else leave with error
				
		decfsz	TEMP1
		goto	Wakeup_Fast_Command_Loop
;
Wakeup_Fast_Command_Try:	
		call	Look4ISO
;
		tstfsz	RRESPONSES,	0			; skip next if no data found
		goto	Wakeup_Fast_Continue
;
		goto	Wakeup_Error
;
Wakeup_Fast_Continue:
		movlw	UPPER OK
		movwf	TBLPTRU
		movlw	HIGH OK
		movwf	TBLPTRH
		movlw	LOW OK
		movwf	TBLPTRL
		call	DisplayMessage
;
		bsf		FLAG1,	AWAKE,	0
		clrf	WREG,	0		
		goto	Wakeup_Exit
;
Wakeup_Slow:
Wakeup_Slow_Active1:		
		movlw	4						; 4 * 2 * 25mS = 200mS
		movwf	TEMP
		bsf		LATB,	K,	0			; set for Active
		bsf		LATB,	L,	0			; set for Active				
		call	T3Wait
;
Wakeup_Slow_Passive1:		
		movlw	8						; 8 * 2 * 25mS = 400mS
		movwf	TEMP
		bcf		LATB,	K,	0			; clear for Passive
		bcf		LATB,	L,	0			; clear for Passive
		call	T3Wait
;
Wakeup_Slow_Active2:
		movlw	UPPER KA
		movwf	TBLPTRU
		movlw	HIGH KA
		movwf	TBLPTRH
		movlw	LOW KA
		movwf	TBLPTRL
		call	DisplayMessageNOCR
;				
		movlw	8						; 8 * 2 * 25mS = 400mS
		movwf	TEMP
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	Wakeup_Error
;				
		bsf		LATB,	K,	0			; set for Active
		bsf		LATB,	L,	0			; set for Active
		call	T3Wait				
;
Wakeup_Slow_Passive2:
		movlw	UPPER KA
		movwf	TBLPTRU
		movlw	HIGH KA
		movwf	TBLPTRH
		movlw	LOW KA
		movwf	TBLPTRL
		call	DisplayMessageNOCR
;						
		movlw	8						; 8 * 2 * 25mS = 400mS
		movwf	TEMP
		bcf		LATB,	K,	0			; clear for Passive
		bcf		LATB,	L,	0			; clear for Passive
		call	T3Wait		
;
Wakeup_Slow_Active3:
		movlw	UPPER KA
		movwf	TBLPTRU
		movlw	HIGH KA
		movwf	TBLPTRH
		movlw	LOW KA
		movwf	TBLPTRL
		call	DisplayMessageNOCR
;						
		movlw	8						; 8 * 2 * 25mS = 400mS
		movwf	TEMP
		btfss	PORTC,	K_SEN,	0		; skip next if passive
		goto	Wakeup_Error
;				
		bsf		LATB,	K,	0			; set for Active
		bsf		LATB,	L,	0			; set for Active
		call	T3Wait						
;
Wakeup_Slow_Passive3:		
		movlw	5						; 5 * 2 * 25mS = 250mS
		movwf	TEMP
		bcf		LATB,	K,	0			; clear for Passive
		bcf		LATB,	L,	0			; clear for Passive
		call	T3Wait
;
Wakeup_Slow_Chk4P3
		movlw	3
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=3
		goto	Wakeup_Slow_Chk4P4
;		
Wakeup_Slow_3:
		movlw	HIGH T3_50MS			; first character 50mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD		
		call	RXISO
;		
		movlw	0x55
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
		call	RXISO
;		
		movlw	0x08
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
		call	RXISO
;		
		movlw	0x08
		cpfseq	CHAR,	0
		goto	Wakeup_Error		
;
		lfsr	2,	TXBBHU
		movlw	0xF7
		movff	WREG,	TXBBHU
		movlw	1
		movwf	TEMP1,	0
;
Wakeup_Slow_3_Wait_Loop1:
;
		movlw	HIGH T3_25MS			; 25mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_25MS
		movwf	TMR3L_RELOAD
		movlw	1						; 25mS
		movwf	TEMP						
		call	T3Wait
;
Wakeup_Slow_3_Send_Loop:		
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		btfsc	RFLAG,	ARBITRATION,	0
		goto	Wakeup_BusBusyError		; else leave with error
;				
		decfsz	TEMP1
		goto	Wakeup_Slow_3_Send_Loop
;
Wakeup_Slow_3_Wait_Loop2:
		movlw	HIGH T3_50MS			; first character 50mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD		
		call	RXISO
;		
		movlw	0xCC
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
		movlw	UPPER OK
		movwf	TBLPTRU
		movlw	HIGH OK
		movwf	TBLPTRH
		movlw	LOW OK
		movwf	TBLPTRL
		call	DisplayMessage
;
		bsf		FLAG1,	AWAKE,	0
		clrf	WREG,	0			
		goto	Wakeup_Exit
;
Wakeup_Slow_Chk4P4:
		movlw	4
		cpfseq	PROTOCOL,	0			; skip next if PROTOCOL=4
		goto	Wakeup_Error
;		
Wakeup_Slow_4:
		movlw	HIGH T3_50MS			; first character 50mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD		
		call	RXISO
;		
		movlw	0x55
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
		call	RXISO
;		
		movlw	0xE9
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
		call	RXISO
;		
		movlw	0x8F
		cpfseq	CHAR,	0
		goto	Wakeup_Error		
;
		lfsr	2,	TXBBHU
		movlw	0x70
		movff	WREG,	TXBBHU
		movlw	1
		movwf	TEMP1,	0
;
Wakeup_Slow_4_Wait_Loop1:
;
		movlw	HIGH T3_25MS			; 25mS 
		movwf	TMR3H_RELOAD
		movlw	LOW T3_25MS
		movwf	TMR3L_RELOAD
		movlw	1						; 25mS
		movwf	TEMP						
		call	T3Wait
;
Wakeup_Slow_4_Send_Loop:		
		movff	POSTINC2,	CHAR		
		call	SendByteISO	
;
		btfsc	RFLAG,	ARBITRATION,	0
		goto	Wakeup_BusBusyError		; else leave with error
;				
		decfsz	TEMP1
		goto	Wakeup_Slow_4_Send_Loop
;
Wakeup_Slow_4_Wait_Loop2:
		movlw	HIGH T3_50MS			; first character 50mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD		
		call	RXISO
;		
		movlw	0xCC
		cpfseq	CHAR,	0
		goto	Wakeup_Error
;
;
		movlw	UPPER OK
		movwf	TBLPTRU
		movlw	HIGH OK
		movwf	TBLPTRH
		movlw	LOW OK
		movwf	TBLPTRL
		call	DisplayMessage
;
		bsf		FLAG1,	AWAKE,	0
		clrf	WREG,	0			
		goto	Wakeup_Exit
;		
Wakeup_BusBusyError:
		bsf		EFLAG,	BBUSY,	0
;
Wakeup_Error:
		movlw	UPPER Err
		movwf	TBLPTRU
		movlw	HIGH Err
		movwf	TBLPTRH
		movlw	LOW Err
		movwf	TBLPTRL
		call	DisplayMessage	
;
		bcf		FLAG1,	AWAKE,	0
		setf	WREG,	0
;
Wakeup_Exit:
		return
;
;***************************************;***************************************
;
;	T3	Wait Loop
;
;	TEMP=1-256 Loops (1-255,0=256)
;	Timer 3 used for TMR3_RELOAD increments
;	RFLAG.ARBITRATION 1=K-SEN is active
;
;	in a passive wait ARBITRATION=1 shows conflict
;	in a active wait ARBITRATION=1 is normal
;
;***************************************;***************************************
;
T3Wait:
		bcf		RFLAG,	ARBITRATION		; clear any arbitration conflicts
;
T3Wait_Loop:
		movff	TMR3H_RELOAD,	TMR3H
		movff	TMR3L_RELOAD,	TMR3L
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;				
T3Wait_Wait:
		btfss	PORTC,	K_SEN,	0		; skip next if passive	
		bsf		RFLAG,	ARBITRATION		; else must be active
		btfss	PIR2,	TMR3IF,	0		; skip if overflow
		goto	T3Wait_Wait		
;
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3				
		decfsz	TEMP,	F,	0
		goto	T3Wait_Loop		
;
T3Wait_Exit:
		return				
;
;***************************************;***************************************
;
;	Begin CAN Transmission
;
;***************************************;***************************************
;
CANTransmit:
		movff	TXBYTE7,	POSTDEC2
		movff	TXBYTE6,	POSTDEC2
		movff	TXBYTE5,	POSTDEC2
		movff	TXBYTE4,	POSTDEC2
		movff	TXBYTE3,	POSTDEC2
		movff	TXBYTE2,	POSTDEC2
		movff	TXBYTE1,	POSTDEC2
		movff	TXBYTE0,	POSTDEC2
		movff	TXBDLC,	POSTDEC2
		movff	TXEIDL,	POSTDEC2
		movff	TXEIDH,	POSTDEC2
		movff	TXSIDL,	POSTDEC2
		movff	TXSIDH,	POSTDEC2
		clrf	RXSTAT,	0
		bsf		INDF2,	TXREQ,	0	; request action
;
CANTransmit_Exit:																
		return
;
;***************************************;***************************************
;
;	Display Message
;
;***************************************;***************************************
;
DisplayMessage:
		call	DisplayMessageNOCR
;		
		call	SendCR
;				
		return
;
;***************************************;***************************************
;
;	Display Message w/NO <cr>
;
;***************************************;***************************************
;
DisplayMessageNOCR:
		
DisplayMessageNOCR_Loop:
		TBLRD*+
		movff	TABLAT,	CHAR
		tstfsz	CHAR,	0				; look for 0x00 (finished)
		goto	DisplayMessageNOCR_Wait
;
		goto	DisplayMessageNOCR_Exit				
;
DisplayMessageNOCR_Wait:		
		call	UserOutput
		tstfsz	WREG
		goto	DisplayMessageNOCR_Wait
;		
		goto	DisplayMessageNOCR_Loop
;
DisplayMessageNOCR_Exit:		
		return
;
;***************************************;***************************************
;
;	Set Protocols
;
;***************************************;***************************************
;
SetProtocol_1:							; SAE J1850 PWM
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	T2_8US		
		movwf	PR2,	0
;		
		movff	P1HEADERU,	HEADERU
		movff	P1HEADERH,	HEADERH
		movff	P1HEADERL,	HEADERL		
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_2:							; SAE J1850 VWP
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	T2_32US		
		movwf	PR2,	0
;		
		movff	P2HEADERU,	HEADERU
		movff	P2HEADERH,	HEADERH
		movff	P2HEADERL,	HEADERL
;	
		movff	PROTOCOL,	LASTPROTOCOL					
		return
;		
SetProtocol_3:							; ISO 9141-2 
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	T2_32US		
		movwf	PR2,	0
;
		bcf		FLAG1,	INIT,	0		; slow init		
;
		movff	P3HEADERU,	HEADERU
		movff	P3HEADERH,	HEADERH
		movff	P3HEADERL,	HEADERL
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_4:							; ISO 14230-4 (KWP 5BAUD)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	T2_32US		
		movwf	PR2,	0
;
		bcf		FLAG1,	INIT,	0		; slow init			
;		
		movff	P4HEADERU,	HEADERU
		movff	P4HEADERH,	HEADERH
		movff	P4HEADERL,	HEADERL
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_5:							; ISO 14230-4 (KWP FAST)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movlw	b'00000100'
		movwf	T2CON,	0				; ON
		movlw	T2_32US		
		movwf	PR2,	0
;
		bsf		FLAG1,	INIT,	0		; fast init			
;		
		movff	P5HEADERU,	HEADERU
		movff	P5HEADERH,	HEADERH
		movff	P5HEADERL,	HEADERL
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_6:							; ISO 15765-4 (11/500)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movff	CANCON,	TEMP1
		movlw	b'10010000'				; Config Mode, Abort transmissions
		movwf	CANCON,	0		
;
Set_6_Wait:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		sublw	b'10000000'
		tstfsz 	WREG 					; skip next if config
		goto 	Set_6_Wait 				; MSBit still zero, Continue to wait...
;
Set_6_BAUD:
		movlw	b'00000001'				; SJW=1Tq, 2*(1+1) BRP=1
		movwf	BRGCON1,	0 
;
		movlw	b'10010001'				; PS2=Freely, SAM=once, PS1=3bits,
										; PT=2bits
		movwf	BRGCON2,	0
;
		movlw	b'10000001'				; Disable Wake-up, PS2=2bits
		movwf	BRGCON3,	0
;
		movff	P6HEADERU,	HEADERU
		movff	P6HEADERH,	HEADERH
		movff	P6HEADERL,	HEADERL
;		
		bcf		FLAG,	HSF,	0		; clear header flag (11-bits)
;		
		rlcf	HEADERL,	W,	0
		rlcf	HEADERH,	W,	0
		andlw	0x0F
		swapf	WREG,	W,	0		
		movwf	TXSIDH,	0
;
		rlcf	HEADERL,	W,	0
		andlw	0xF0
		swapf	WREG,	W,	0
		iorwf	TXSIDH,	F,	0
;
		bcf		STATUS,	C,	0
		rlcf	HEADERL,	W,	0
		andlw	0x0F
		swapf	WREG,	W,	0
		clrf	TXSIDL,	0		
		iorwf	TXSIDL,	F,	0		
;		
 		clrf	TXEIDH
 		clrf	TXEIDL	
 		movlw	D'8'
 		movwf	TXBDLC,	0
		movff	TEMP1,	CANCON			; put it back the way it was
;
Set_6_Wait1:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		tstfsz 	WREG,	0 					; skip next if normal
		goto 	Set_6_Wait1 			; MSBit still one, Continue to wait...		
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_7:							; ISO 15765-4 (29/500)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movff	CANCON,	TEMP1
		movlw	b'10010000'				; Config Mode, Abort transmissions
		movwf	CANCON,	0		
;
Set_7_Wait:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		sublw	b'10000000'
		tstfsz 	WREG 					; skip next if config
		goto 	Set_7_Wait 				; MSBit still zero, Continue to wait...
;		
Set_7_BAUD:	
		movlw	b'00000001'				; SJW=1Tq, 2*(1+1) BRP=1
		movwf	BRGCON1,	0 
;
		movlw	b'10010001'				; PS2=Freely, SAM=once, PS1=3bits,
										; PT=2bits
		movwf	BRGCON2,	0
;
		movlw	b'10000001'				; Disable Wake-up, PS2=2bits
		movwf	BRGCON3,	0
;
		movff	P7HEADERU,	HEADERU
		movff	P7HEADERH,	HEADERH
		movff	P7HEADERL,	HEADERL
;		
		bsf		FLAG,	HSF,	0		; set header flag (19-bits)
		
		movff	PRIORITY,	TXSIDH
		movff	HEADERU,	TEMP
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0		
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0		
;
		movf	TEMP,	W,	0
		andlw	0xC0
		movwf	TXSIDL,	0
		bsf		TXSIDL,	EXIDE,	0
		movf	HEADERU,	W,	0
		andlw	0x03
		iorwf	TXSIDL,	F,	0
;
		movff	HEADERH,	TXEIDH
		movff	HEADERL,	TXEIDL		
 		movlw	D'8'
 		movwf	TXBDLC,	0	
		movff	TEMP1,	CANCON			; put it back the way it was
;
Set_7_Wait1:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		tstfsz 	WREG,	0 					; skip next if normal
		goto 	Set_7_Wait1 			; MSBit still one, Continue to wait...		
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_8:							; ISO 15765-4 (11/250)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movff	CANCON,	TEMP1
		movlw	b'10010000'				; Config Mode, Abort transmissions
		movwf	CANCON,	0		
;
Set_8_Wait:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		sublw	b'10000000'
		tstfsz 	WREG 					; skip next if config
		goto 	Set_8_Wait 				; MSBit still zero, Continue to wait...
;
Set_8_BAUD:	
		movlw	b'00000011'				; SJW=1Tq, 2*(3+1) BRP=3
		movwf	BRGCON1,	0 
;
		movlw	b'10010001'				; PS2=Freely, SAM=once, PS1=3bits,
										; PT=2bits
		movwf	BRGCON2,	0
;
		movlw	b'10000001'				; Disable Wake-up, PS2=2bits
		movwf	BRGCON3,	0
;
		movff	P8HEADERU,	HEADERU
		movff	P8HEADERH,	HEADERH
		movff	P8HEADERL,	HEADERL
;		
		bcf		FLAG,	HSF,	0		; clear header flag (11-bits)
;		
		rlcf	HEADERL,	W,	0
		rlcf	HEADERH,	W,	0
		andlw	0x0F
		swapf	WREG,	W,	0		
		movwf	TXSIDH,	0
;
		rlcf	HEADERL,	W,	0
		andlw	0xF0
		swapf	WREG,	W,	0
		iorwf	TXSIDH,	F,	0
;
		bcf		STATUS,	C,	0
		rlcf	HEADERL,	W,	0
		andlw	0x0F
		swapf	WREG,	W,	0
		clrf	TXSIDL,	0		
		iorwf	TXSIDL,	F,	0		
;		
 		clrf	TXEIDH
 		clrf	TXEIDL	
 		movlw	D'8'
 		movwf	TXBDLC,	0 
		movff	TEMP1,	CANCON			; put it back the way it was 												
;
Set_8_Wait1:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		tstfsz 	WREG,	0 					; skip next if normal
		goto 	Set_8_Wait1 			; MSBit still one, Continue to wait...		
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;		
SetProtocol_9:							; ISO 15765-4 (29/250)
		bcf		FLAG1,	AWAKE,	0		; stop any auto polls
		movff	CANCON,	TEMP1
		movlw	b'10010000'				; Config Mode, Abort transmissions
		movwf	CANCON,	0		
;
Set_9_Wait:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		sublw	b'10000000'
		tstfsz 	WREG 					; skip next if config
		goto 	Set_9_Wait 				; MSBit still zero, Continue to wait...
;		
Set_9_BAUD:	
		movlw	b'00000011'				; SJW=1Tq, 2*(1+3) BRP=3
		movwf	BRGCON1,	0 
;
		movlw	b'10010001'				; PS2=Freely, SAM=once, PS1=3bits,
										; PT=2bits
		movwf	BRGCON2,	0
;
		movlw	b'10000001'				; Disable Wake-up, PS2=2bits
		movwf	BRGCON3,	0
;
		movff	P9HEADERU,	HEADERU
		movff	P9HEADERH,	HEADERH
		movff	P9HEADERL,	HEADERL
;		
		bsf		FLAG,	HSF,	0		; set header flag (29-bits)
;		
		movff	PRIORITY,	TXSIDH
		movff	HEADERU,	TEMP
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0		
		rlcf	TEMP,	F,	0
		rlcf	TXSIDH,	F,	0		
;
		movf	TEMP,	W,	0
		andlw	0xC0
		movwf	TXSIDL,	0
		bsf		TXSIDL,	EXIDE,	0
		movf	HEADERU,	W,	0
		andlw	0x03
		iorwf	TXSIDL,	F,	0
;
		movff	HEADERH,	TXEIDH
		movff	HEADERL,	TXEIDL		
 		movlw	D'8'
 		movwf	TXBDLC,	0	
		movff	TEMP1,	CANCON			; put it back the way it was  												
;
Set_9_Wait1:
		movf 	CANSTAT, W,	0			; Read current mode state.
		andlw 	b'11100000' 			; Interested in OPMODE bit only.
		tstfsz 	WREG,	0 					; skip next if normal
		goto 	Set_9_Wait1 			; MSBit still one, Continue to wait...		
;
		movff	PROTOCOL,	LASTPROTOCOL						
		return
;
;***************************************;***************************************
;
;	Look For J1850 PWM response from ECU
;
;	Timer 3 provides the timeout counter
;	RRESPONSES = number of separate replies (1 timeout between responses)
;	RCOUNT = number of bytes found before timeout
;	RFLAG.GOTDATA 0=no character
;	RFLAG.FRAME 1=framing error
;
;	interrupts disabled
;
;	sholud get an ECM response in <1mS
;	ACK (0xF1) immediately (no SOP) or ECM will retry 3 times
;	there will be about 80uS between additional ECU's responses  
;
;***************************************;***************************************
;
Look4PWM:								; look for SOF
		clrf	RRESPONSES,	0		
		bcf		INTCON,	GIEH,	0
		bcf		INTCON,	GIEL,	0
;
Look4PWM_ResponseLoop:	
		lfsr	2,	RX1COUNT			
		movlw	D'13'					; length of response buffer
		mulwf	RRESPONSES,	0	
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0		
		clrf	POSTINC2,	0
		clrf	RXCOUNT,	0	
		bcf		T3CON,	TMR3ON,	0		
		movlw	HIGH T3_5MS				; first character 5mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_5MS
		movwf	TMR3L_RELOAD
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
Look4PWM_Chk4SOF_Active:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	Look4PWM_Exit			; else timeout
;
		btfss	PORTC,	B_PLUS_SEN,	0	; skip next if Active (1)
;		btfsc	PORTC,	B_MINUS_SEN,	0	; skip next if Active (0)		
		goto	Look4PWM_Chk4SOF_Active
;
		bcf		T3CON,	TMR3ON,	0
		setf	TMR3H,	0
		movlw	0x80					; 16 * 2uS = 32uS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0
		bcf		PIR2,	TMR3IF,	0
;
Look4PWM_Chk4SOF_Passive:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	Look4PWM_Exit			; else timeout
;
		btfsc	PORTC,	B_PLUS_SEN,	0	; skip next if Passive (1)
;		btfss	PORTC,	B_MINUS_SEN,	0	; skip next if Passive (0)		
		goto	Look4PWM_Chk4SOF_Passive
;
		bcf		T3CON,	TMR3ON,	0		
		setf	TMR3H,	0
		movlw	0x80					; 16 * 2uS = 32uS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow				
;
Look4PWM_Loop:
		call	RXPWM
;
		btfss	RFLAG,	GOTDATA,	0	; skip next if got data
		goto	Look4PWM_TryAnother		; else timeout
;
Look4PWM_GotOne:
		incf	RXCOUNT,	F,	0
		movff	CHAR,	POSTINC2
		goto	Look4PWM_Loop
;		
Look4PWM_TryAnother:	
		movlw	0xF1
		movwf	CHAR,	0
		call	SendBytePWM
;			
		lfsr	2,	RX1COUNT
		movlw	D'13'					; length of response buffer
		mulwf	RRESPONSES,	0	
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0		
		movff	RXCOUNT,	INDF2		; replace the zero with the real count
		incf	RRESPONSES,	F,	0
		clrf	RXCOUNT,	0
		goto	Look4PWM_ResponseLoop		
;
Look4PWM_Exit:
		bsf		INTCON,	GIEH,	0
		bsf		INTCON,	GIEL,	0
		return
;
;***************************************;***************************************
;
;	Look For J1850 PWM IFR response from ECU
;
;	Timer 3 provides the timeout counter
;	RCOUNT = number of bytes found before timeout
;	RFLAG.GOTDATA 0=no character
;
;	interrupts disabled
;
;	ECU should respond immediately with an ACK (0x10) with <1mS between
;	this ACK and the ECU's response 
;
;***************************************;***************************************
;
Look4PWMIFR:								
		bcf		INTCON,	GIEH,	0
		bcf		INTCON,	GIEL,	0
		lfsr	2,	RXCOUNT			
		clrf	POSTINC2,	0	
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3		
		setf	TMR3H,	0
		movlw	0x80					; 16 * 2uS = 32uS
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow				
;
Look4PWMIFR_Loop:
		call	RXPWM
;
		btfss	RFLAG,	GOTDATA,	0	; skip next if got data
		goto	Look4PWMIFR_Exit		; else timeout
;
Look4PWMIFR_GotOne:
		incf	RXCOUNT,	F,	0
		movff	CHAR,	POSTINC2
		goto	Look4PWMIFR_Loop
;		
Look4PWMIFR_Exit:
		bsf		INTCON,	GIEH,	0
		bsf		INTCON,	GIEL,	0
		return		
;
;***************************************;***************************************
;
;	Look For J1850 PWM byte (41,200 baud)
;
;	enters RXPWM in Passive mode
;	RXPWM waits for Active mode then Passive and measures time Active
;	less than 12uS is a '1' else '0'
;	RXPWM leaves after 8bits or a timeout
;
;	Timer 3 provides the timeout counter
;	TMR3H:L=0xFF00 (500uS)
;	PWM byte is returned in CHAR (8 data bits)
;	RFLAG.GOTDATA 0=no character (timeout)
;
;	should have interrupts disabled
;
;***************************************;***************************************
;
RXPWM:
		movlw	8
		movwf	TEMP,	0
		bcf		RFLAG,	GOTDATA,	0	; clear	
;
RXPWM_Chk4Bit_Active:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	RXPWM_Exit				; else timeout
;
		btfss	PORTC,	B_PLUS_SEN,	0	; skip next if Active (1)
;		btfsc	PORTC,	B_MINUS_SEN,	0	; skip next if Active (0)		
		goto	RXPWM_Chk4Bit_Active
;
		bcf		T3CON,	TMR3ON,	0
		setf	TMR3H,	0
		movlw	0x80
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0
		bcf		PIR2,	TMR3IF,	0
;		
RXPWM_Chk4Bit_Passive:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	RXPWM_Exit				; else timeout
;
		btfsc	PORTC,	B_PLUS_SEN,	0	; skip next if Passive (0)
;		btfss	PORTC,	B_MINUS_SEN,	0	; skip next if Passive (0)		
		goto	RXPWM_Chk4Bit_Passive
;
		bcf		T3CON,	TMR3ON,	0
		bcf		TMR3L,	7,	0			; clear MSBit
		movlw	5
		bcf		STATUS,	C,	0			; preset CARRY to long '0'
		cpfsgt	TMR3L,	0				; skip next if TMR3L>5 (6*2uS=12uS) 
		bsf		STATUS,	C,	0			; else short '1'
		rlcf	CHAR,	F,	0			; bit value (B_PLUS_SEN)into CHAR
		setf	TMR3H,	0
		movlw	0xF0
		movwf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0
		bcf		PIR2,	TMR3IF,	0
;		
		decfsz	TEMP,	F,	0			; skip next if TEMP=0		
		goto	RXPWM_Chk4Bit_Active
;
RXPWM_Done
		bsf		RFLAG,	GOTDATA,	0	; set
;
RXPWM_Exit:
		return	
;
;***************************************;***************************************
;
;	Look For J1850 VPW response from ECU
;
;	Timer 3 provides the timeout counter
;	RRESPONSES = number of separate replies (1 timeout between responses)
;	RCOUNT = number of bytes found before timeout
;	RFLAG.GOTDATA 0=no character
;	RFLAG.FRAME 1=framing error
;
;	interrupts disabled
;
;	sholud get an ECM response in <1.5mS
;	there will be about <800uS between additional ECU's responses  
;
;***************************************;***************************************
;
Look4VPW:								; look for SOF
		clrf	RRESPONSES,	0		
		bcf		INTCON,	GIEH,	0
		bcf		INTCON,	GIEL,	0
;
Look4VPW_ResponseLoop:
		lfsr	2,	RX1COUNT			
		movlw	D'13'					; length of response buffer
		mulwf	RRESPONSES,	0	
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0		
		clrf	POSTINC2,	0
		clrf	RXCOUNT,	0	
;
		bcf		T3CON,	TMR3ON,	0		
		movlw	0xFD					; 768 * 2uS ~ 1.5mS		
		movwf	TMR3H,	0
		clrf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow			
;
Look4VPW_Chk4SOF_Active:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	Look4VPW_Exit			; else timeout
;
		btfss	PORTC,	B_PLUS_SEN,	0	; skip next if Active (1)
		goto	Look4VPW_Chk4SOF_Active
;		
		bcf		T3CON,	TMR3ON,	0		
		setf	TMR3H,	0				; 256 * 2uS ~ 500uS
		clrf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow
;
Look4VPW_Chk4SOF_Passive:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	Look4VPW_Exit			; else timeout
;
		btfsc	PORTC,	B_PLUS_SEN,	0	; skip next if Passive (0)
		goto	Look4VPW_Chk4SOF_Passive
;
		bcf		T3CON,	TMR3ON,	0		; stop the timer 3
		movlw	D'80'					; 80 * 2uS = 160uS
		cpfsgt	TMR3L	,0				; skip next if TMR3L > 160uS
		goto	Look4VPW_Exit			; else not a SOF 
;
		movlw	D'120'					; 120 * 2uS = 240uS
		cpfslt	TMR3L	,0				; skip next if TMR3L < 240uS
		goto	Look4VPW_Exit			; else not a SOF 		
; 
		setf	TMR3H,	0				; 256 * 2uS ~ 500uS
		clrf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3 
		bcf		PIR2,	TMR3IF,	0		; clear any overflow				
;
Look4VPW_Loop:
		call	RXVPW
;
		btfss	RFLAG,	GOTDATA,	0	; skip next if got data
		goto	Look4VPW_Chk4Characters	; else timeout
;
Look4VPW_GotOne:
		incf	RXCOUNT,	F,	0
		movff	CHAR,	POSTINC2
		goto	Look4VPW_Loop
;		
Look4VPW_Chk4Characters:
		tstfsz	RXCOUNT,	0			; skip next if no characters received
		goto	Look4VPW_TryAnother		; else still receiving, look for more
;
		goto	Look4VPW_Exit			; done here		
;		
Look4VPW_TryAnother:			
		lfsr	2,	RX1COUNT
		movlw	D'13'					; length of response buffer
		mulwf	RRESPONSES,	0	
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0		
		movff	RXCOUNT,	INDF2		; replace the zero with the real count
		incf	RRESPONSES,	F,	0
		clrf	RXCOUNT,	0
		goto	Look4VPW_ResponseLoop		
;
Look4VPW_Exit:
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		bsf		INTCON,	GIEH,	0
		bsf		INTCON,	GIEL,	0
		return
;
;***************************************;***************************************
;
;	Look For J1850 VPW byte (10,400 baud)
;
;	enters RXPWM in Passive mode timing period
;	look for Active and compare Passive period
;	Passive > 96uS = '1' else '0'
;	Change to Active state and start timer
;	look for Passive and compare Active period
;	Active > 96uS = '0' else '1'
;	enters RXPWM in Passive mode timing period
;	Change to Passive state and start timer
;	RXPWM leaves after 8bits or a timeout
;
;	Timer 3 provides the timeout counter
;	TMR3H:L=0xFF00 (500uS)
;	PWM byte is returned in CHAR (8 data bits)
;	RFLAG.GOTDATA 0=no character (timeout)
;
;	should have interrupts disabled
;
;***************************************;***************************************
;
RXVPW:
		movlw	4
		movwf	TEMP,	0
		bcf		RFLAG,	GOTDATA,	0	; clear	
;
RXVPW_Chk4Bit_Active:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	RXVPW_Exit				; else timeout
;
		btfss	PORTC,	B_PLUS_SEN,	0	; skip next if Active (1)
		goto	RXVPW_Chk4Bit_Active
;
		bcf		T3CON,	TMR3ON,	0
		movlw	D'48'					; 96uS	
		bsf		STATUS,	C,	0			; preset bit to a '1'	
		cpfsgt	TMR3L,	0				; skip next if TMR3>96uS
		bcf		STATUS,	C,	0			; else clear bit to a '0'
		rlcf	CHAR,	F,	0			; bit value (B_PLUS_SEN)into CHAR							
;	
		setf	TMR3H,	0
		clrf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0
		bcf		PIR2,	TMR3IF,	0
;		
RXVPW_Chk4Bit_Passive:
		btfsc	PIR2,	TMR3IF,	0		; skip next if no overflow
		goto	RXVPW_Exit				; else timeout
;
		btfsc	PORTC,	B_PLUS_SEN,	0	; skip next if Passive (0)
		goto	RXVPW_Chk4Bit_Passive
;
		bcf		T3CON,	TMR3ON,	0
		movlw	D'48'					; 96uS	
		bcf		STATUS,	C,	0			; preset bit to a '0'	
		cpfsgt	TMR3L,	0				; skip next if TMR3>96uS
		bsf		STATUS,	C,	0			; else clear bit to a '1'
		rlcf	CHAR,	F,	0			; bit value (B_PLUS_SEN)into CHAR							
;	
		setf	TMR3H,	0
		clrf	TMR3L,	0
		bsf		T3CON,	TMR3ON,	0
		bcf		PIR2,	TMR3IF,	0
;		
		decfsz	TEMP,	F,	0			; skip next if TEMP=0		
		goto	RXVPW_Chk4Bit_Active
;
RXVPW_Done
		bsf		RFLAG,	GOTDATA,	0	; set
;
RXVPW_Exit:
		return		
;
;***************************************;***************************************
;
;	Look For ISO reception
;
;	Timer 3 provides the timeout counter
;	RRESPONSES = number of separate replies (1 timeout between responses)
;	RCOUNT = number of bytes found before timeout
;	T3_50MS time is used for first character timeout 
;	T3_20MS time is for additional character timeout
;	RCOUNT = number of bytes found before timeout
;	RFLAG.GOTDATA 0=no character
;	RFLAG.FRAME 1=framing error
;
;	interrupts disabled
;
;***************************************;***************************************
;
Look4ISO:
		clrf	RRESPONSES,	0
		bcf		INTCON,	GIEH,	0
		bcf		INTCON,	GIEL,	0
;
Look4ISO_Response_Loop:	
		lfsr	2,	RX1COUNT
		movlw	D'13'
		mulwf	RRESPONSES,	0
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0
		clrf	POSTINC2,	0	
		clrf	RXCOUNT,	0
;		
		movlw	HIGH T3_50MS			; first character 50mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_50MS
		movwf	TMR3L_RELOAD		
;
Look4ISO_Loop:
		call	RXISO
;
		movlw	HIGH T3_20MS			; additional characters 20mS max
		movwf	TMR3H_RELOAD
		movlw	LOW T3_20MS
		movwf	TMR3L_RELOAD		
		
		btfss	RFLAG,	GOTDATA,	0	; skip next if got data
		goto	Look4ISO_Chk4Characters
;
Look4ISO_GotOne:
		incf	RXCOUNT,	F,	0
		movff	CHAR,	POSTINC2
		goto	Look4ISO_Loop	
;
Look4ISO_Chk4Characters:
		tstfsz	RXCOUNT,	0			; skip next if no characters received
		goto	Look4ISO_Chk4TryAnother	; else still receiving, look for more
;
		goto	Look4ISO_Exit	
;
Look4ISO_Chk4TryAnother:
		lfsr	2,	RX1COUNT
		movlw	D'13'					; length of response buffer
		mulwf	RRESPONSES,	0
		movf	PRODL,	W,	0
		addwf	FSR2L,	F,	0
		movff	RXCOUNT,	INDF2		; replace zero with the real count
		incf	RRESPONSES,	F,	0	
		clrf	RXCOUNT,	0
		goto	Look4ISO_Response_Loop						
;
Look4ISO_Exit:
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3
		bsf		INTCON,	GIEH,	0
		bsf		INTCON,	GIEL,	0
		return
;
;***************************************;***************************************
;
;	Look For ISO byte
;
;	Timer 3 provides the timeout counter
;	T3_50MS time is used for first character timeout 
;	T3_20MS time is for additional character timeout
;	ISO byte is returned in CHAR (start bit, 8 data bits, stop bit)
;	Timer 2 provides a 1/3 bit time (32uS for 10400 baud)
;	samples @ 2/3 of each bit time (2nd of 3 timer 2 loops for each bit)
;	RFLAG.GOTDATA 0=no character
;	RFLAG.FRAME 1=framing error
;
;	should have interrupts disabled
;
;***************************************;***************************************
;
RXISO:
		bcf		RFLAG,	FRAME,	0		; clear 
		bcf		RFLAG,	GOTDATA,	0	; clear	
		movff	TMR3H_RELOAD,	TMR3H
		movff	TMR3L_RELOAD,	TMR3L
		bsf		T3CON,	TMR3ON,	0		; turn ON timer 3
		bcf		PIR2,	TMR3IF,	0		; clear any overflow				
;
RXISO_Chk4StartBit_Active:
		btfsc	PIR2,	TMR3IF,0		; skip next if no overflow
		goto	RXISO_Exit				; else timeout
;		
		btfsc	PORTC,	K_SEN,	0		; skip next if Active (0)
		goto	RXISO_Chk4StartBit_Active
;
RXISO_GotStartBit_Active:
		clrf	TMR2,	0				; restart timer 2
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_StartBit_Loop1:					; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_StartBit_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_StartBit_Loop2:					; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_StartBit_Loop2
;
RXISO_StartBit_Sample:
		btfsc	PORTC,	K_SEN,	0		; skip next if Active (legal)
		goto	RXISO_Chk4StartBit_Active	; else Passive, try again
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_StartBit_Loop3:					; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_StartBit_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_Byte:								; now the data
		movlw	8
		movwf	TEMP,	0
;
RXISO_Bit_Loop1:						; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_Bit_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_Bit_Loop2:						; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_Bit_Loop2
;
RXISO_Bit_Sample:
		bsf		STATUS,	C,	0			; preset Carry
		btfss	PORTC,	K_SEN,	0		; skip K_SEN is Passive
		bcf		STATUS,	C,	0			; else clear Carry
		rrcf	CHAR,	F,	0			; bit value (K_SEN)into CHAR
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_Bit_Loop3:						; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_Bit_Loop3
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
		decfsz	TEMP,	F,	0			; skip next if no more bits
		goto	RXISO_Bit_Loop1			; else get another bit
;
RXISO_StopBit_Loop1:					; wait one 1/3 bit		
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_StopBit_Loop1
;
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
;
RXISO_StopBit_Loop2:					; wait one 1/3 bit
		btfss	PIR1,	TMR2IF,0		; skip next if overflow
		goto	RXISO_StopBit_Loop2
;
RXISO_StopBit_Sample:
		bcf		PIR1,	TMR2IF,	0		; clear any overflow
		btfss	PORTC,	K_SEN,	0		; skip K_SEN is Passive (stop bit)
		bsf		RFLAG,	FRAME,	0		; else framing error
;
; skipping last 1/2 of the stop bit so we can get back in time for the next byte		
;
RXISO_GotByte:							
		bsf		RFLAG,	GOTDATA,	0	; got a character
;		
RXISO_Exit:	
		bcf		T3CON,	TMR3ON,	0		; turn OFF timer 3	
		return							
;
;***************************************;***************************************
;
;	Message Area
;
;***************************************;***************************************
;

SignON:
		data	"ELM327 V1.3a",0
P0:	
		data	"AUTO",0
P1:	
		data	"SAE J1850 PWM",0
P2:	
		data	"SAE J1850 VWP",0
P3:	
		data	"ISO 9141-2",0
P4:	
		data	"ISO 14230-4 (KWP 5BAUD)",0
P5:	
		data	"ISO 14230-4 (KWP FAST)",0
P6:	
		data	"ISO 15765-4 (CAN 11/500)",0
P7:	
		data	"ISO 15765-4 (CAN 29/500)",0
P8:		
		data	"ISO 15765-4 (CAN 11/250)",0
P9:	
		data	"ISO 15765-4 (CAN 29/250)",0
DF0:	
		data	"CAN ",0
DF1:	
		data	"ISO 15765-4 ",0
DF2:	
		data	"SAE J1939 ",0
TIDL0:	
		data	"29/",0
TIDL1:	
		data	"11/",0
DL0:	
		data	"DLC=8 ",0
DL1:	
		data	"DLC=variable ",0	
RIDL0:	
		data	"RIDL=TIDL ",0
RIDL1:	
		data	"RIDL=11&29 ",0
BRM0:	
		data	"BAUD*1 ",0
BRM1:	
		data	"BAUD*8/7 ",0
BAUD250:
		data	"(250)",0
BAUD125:
		data	"(125)",0
BAUD50:
		data	"(50)",0							
Err:
		data	"ERROR",0
BufferFull:
		data	"BUFFER FULL",0	
BusBusy:
		data	"BUS BUSY",0
DataError:
		data	"DATA ERROR",0
NoData:
		data	"NO DATA",0
UnableToConnect:
		data	"UNABLE TO CONNECT",0							
BusInit:
		data	"BUS INIT:",0
KA:
		data	".",0
OK:
		data	"OK",0	
;
		packed code_pack
CRCTABLE:; (previous CRC value) XOR (new DATA value) gives an offset into this table for a (new CRC value)		
CRC0:     DB     0x00, 0x1D, 0x3A, 0x27, 0x74, 0x69, 0x4E, 0x53, 0xE8, 0xF5, 0xD2, 0xCF, 0x9C, 0x81, 0xA6, 0xBB 
CRC1:     DB     0xCD, 0xD0, 0xF7, 0xEA, 0xB9, 0xA4, 0x83, 0x9E, 0x25, 0x38, 0x1F, 0x02, 0x51, 0x4C, 0x6B, 0x76 
CRC2:     DB     0x87, 0x9A, 0xBD, 0xA0, 0xF3, 0xEE, 0xC9, 0xD4, 0x6F, 0x72, 0x55, 0x48, 0x1B, 0x06, 0x21, 0x3C 
CRC3:     DB     0x4A, 0x57, 0x70, 0x6D, 0x3E, 0x23, 0x04, 0x19, 0xA2, 0xBF, 0x98, 0x85, 0xD6, 0xCB, 0xEC, 0xF1 
CRC4:     DB     0x13, 0x0E, 0x29, 0x34, 0x67, 0x7A, 0x5D, 0x40, 0xFB, 0xE6, 0xC1, 0xDC, 0x8F, 0x92, 0xB5, 0xA8 
CRC5:     DB     0xDE, 0xC3, 0xE4, 0xF9, 0xAA, 0xB7, 0x90, 0x8D, 0x36, 0x2B, 0x0C, 0x11, 0x42, 0x5F, 0x78, 0x65 
CRC6:     DB     0x94, 0x89, 0xAE, 0xB3, 0xE0, 0xFD, 0xDA, 0xC7, 0x7C, 0x61, 0x46, 0x5B, 0x08, 0x15, 0x32, 0x2F 
CRC7:     DB     0x59, 0x44, 0x63, 0x7E, 0x2D, 0x30, 0x17, 0x0A, 0xB1, 0xAC, 0x8B, 0x96, 0xC5, 0xD8, 0xFF, 0xE2 
CRC8:     DB     0x26, 0x3B, 0x1C, 0x01, 0x52, 0x4F, 0x68, 0x75, 0xCE, 0xD3, 0xF4, 0xE9, 0xBA, 0xA7, 0x80, 0x9D 
CRC9:     DB     0xEB, 0xF6, 0xD1, 0xCC, 0x9F, 0x82, 0xA5, 0xB8, 0x03, 0x1E, 0x39, 0x24, 0x77, 0x6A, 0x4D, 0x50 
CRCA:     DB     0xA1, 0xBC, 0x9B, 0x86, 0xD5, 0xC8, 0xEF, 0xF2, 0x49, 0x54, 0x73, 0x6E, 0x3D, 0x20, 0x07, 0x1A 
CRCB:     DB     0x6C, 0x71, 0x56, 0x4B, 0x18, 0x05, 0x22, 0x3F, 0x84, 0x99, 0xBE, 0xA3, 0xF0, 0xED, 0xCA, 0xD7 
CRCC:     DB     0x35, 0x28, 0x0F, 0x12, 0x41, 0x5C, 0x7B, 0x66, 0xDD, 0xC0, 0xE7, 0xFA, 0xA9, 0xB4, 0x93, 0x8E 
CRCD:     DB     0xF8, 0xE5, 0xC2, 0xDF, 0x8C, 0x91, 0xB6, 0xAB, 0x10, 0x0D, 0x2A, 0x37, 0x64, 0x79, 0x5E, 0x43 
CRCE:     DB     0xB2, 0xAF, 0x88, 0x95, 0xC6, 0xDB, 0xFC, 0xE1, 0x5A, 0x47, 0x60, 0x7D, 0x2E, 0x33, 0x14, 0x09 
CRCF:     DB     0x7F, 0x62, 0x45, 0x58, 0x0B, 0x16, 0x31, 0x2C, 0x97, 0x8A, 0xAD, 0xB0, 0xE3, 0xFE, 0xD9, 0xC4 
;
;***************************************;***************************************
;
;	End of program
;
;***************************************;***************************************
;
		END
